@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2016-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2016-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -19,8 +19,8 @@
 
 #include <QSettings>
 
-#include "entry.h"
-#include "onlinesearchabstract.h"
+#include <Entry>
+#include <onlinesearch/OnlineSearchAbstract>
 
 const int SortedBibliographyModel::SortAuthorNewestTitle = 0;
 const int SortedBibliographyModel::SortAuthorOldestTitle = 1;
@@ -36,6 +36,7 @@ SortedBibliographyModel::SortedBibliographyModel()
     setDynamicSortFilter(true);
     sort(0);
     connect(model, &BibliographyModel::busyChanged, this, &SortedBibliographyModel::busyChanged);
+    connect(model, &BibliographyModel::progressChanged, this, &SortedBibliographyModel::progressChanged);
 }
 
 SortedBibliographyModel::~SortedBibliographyModel() {
@@ -66,6 +67,13 @@ bool SortedBibliographyModel::isBusy() const {
         return false;
 }
 
+int SortedBibliographyModel::progress() const {
+    if (model != nullptr)
+        return model->progress();
+    else
+        return -1;
+}
+
 int SortedBibliographyModel::sortOrder() const {
     return m_sortOrder;
 }
@@ -80,10 +88,14 @@ void SortedBibliographyModel::setSortOrder(int _sortOrder) {
 
 QStringList SortedBibliographyModel::humanReadableSortOrder() const {
     static const QStringList result {
-                                     tr("Last name, newest first"), ///< SortAuthorNewestTitle
-                                     tr("Last name, oldest first"), ///< SortAuthorOldestTitle
-                                     tr("Newest first, last name"), ///< SortNewestAuthorTitle
-                                     tr("Oldest first, last name")  ///< SortOldestAuthorTitle
+                                     //% "Last name, newest first"
+                                     qtTrId("sortorder-humanreadable-lastname-newestfirst"), ///< SortAuthorNewestTitle
+                                     //% "Last name, oldest first"
+                                     qtTrId("sortorder-humanreadable-lastname-oldestfirst"), ///< SortAuthorOldestTitle
+                                     //% "Newest first, last name"
+                                     qtTrId("sortorder-humanreadable-newestfirst-lastname"), ///< SortNewestAuthorTitle
+                                     //% "Oldest first, last name"
+                                     qtTrId("sortorder-humanreadable-oldestfirst-lastname")  ///< SortOldestAuthorTitle
                                     };
     return result;
 }
@@ -203,6 +215,7 @@ BibliographyModel::BibliographyModel() {
     m_searchEngineList = new SearchEngineList();
     connect(m_searchEngineList, &SearchEngineList::foundEntry, this, &BibliographyModel::newEntry);
     connect(m_searchEngineList, &SearchEngineList::busyChanged, this, &BibliographyModel::busyChanged);
+    connect(m_searchEngineList, &SearchEngineList::progressChanged, this, &BibliographyModel::progressChanged);
 }
 
 BibliographyModel::~BibliographyModel() {
@@ -260,10 +273,13 @@ QVariant BibliographyModel::data(const QModelIndex &index, int role) const {
             const bool isPhdThesis = curEntry->type() == Entry::etPhDThesis;
             if (isPhdThesis) {
                 const QString school = valueToText(curEntry->operator[](Entry::ftSchool));
-                if (school.isEmpty())
-                    return tr("Doctoral dissertation");
-                else
-                    return tr("Doctoral dissertation (%1)").arg(school);
+                if (school.isEmpty()) {
+                    //% "Doctoral dissertation"
+                    return qtTrId("wherepublished-doctoral-dissertation");
+                } else {
+                    //% "Doctoral dissertation (%1)"
+                    return qtTrId("wherepublished-doctoral-dissertation-arg").arg(school);
+                }
             }
             const QString school = valueToText(curEntry->operator[](Entry::ftSchool));
             if (!school.isEmpty()) return school;
@@ -275,8 +291,12 @@ QVariant BibliographyModel::data(const QModelIndex &index, int role) const {
             switch (authors.size()) {
             case 0: return QString(); ///< empty list of authors
             case 1: return authors.first(); ///< single author
-            case 2: return tr("%1 and %2").arg(authors.first()).arg(authors[1]); ///< two authors
-            default: return tr("%1 and %2 more").arg(authors.first()).arg(QString::number(authors.size() - 1)); ///< three or more authors
+            case 2:
+                //% "%1 and %2"
+                return qtTrId("shortauthors-two-author-args").arg(authors.first()).arg(authors[1]); ///< two authors
+            default:
+                //% "%1 and %2 more"
+                return qtTrId("shortauthors-one-author-arg-and-n-others-arg").arg(authors.first()).arg(QString::number(authors.size() - 1)); ///< three or more authors
             }
         } else if (role == UrlRole) {
             const QStringList doiList = valueToList(curEntry->operator[](Entry::ftDOI));
@@ -308,6 +328,8 @@ void BibliographyModel::startSearch(const QString &freeText, const QString &titl
     query[OnlineSearchAbstract::queryKeyTitle] = title;
     query[OnlineSearchAbstract::queryKeyAuthor] = author;
 
+    m_searchEngineList->resetProgress();
+
     m_runningSearches = 0;
     const QSettings settings(QStringLiteral("harbour-bibsearch"), QStringLiteral("BibSearch"));
     for (int i = 0; i < m_searchEngineList->size(); ++i) {
@@ -332,6 +354,10 @@ bool BibliographyModel::isBusy() const {
     return false;
 }
 
+int BibliographyModel::progress() const {
+    return m_searchEngineList->progress();
+}
+
 void BibliographyModel::searchFinished() {
     --m_runningSearches;
 }
