@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2021 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -64,8 +64,7 @@ void FileModel::notificationEvent(int eventId)
     } else if (eventId == NotificationHub::EventBibliographySystemChanged) {
         beginResetModel();
         endResetModel();
-        emit headerDataChanged(Qt::Horizontal, 0, 0xffff);
-        emit dataChanged(index(0, 0), index(rowCount() - 1, columnCount() - 1));
+        emit bibliographySystemChanged();
     }
 }
 
