@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,7 +22,6 @@
 #include <QSet>
 #include <QString>
 #include <QStringList>
-#include <QDebug>
 #include <QRegularExpression>
 
 #ifdef HAVE_KF5
@@ -33,8 +32,9 @@
 #define i18n(text) QObject::tr(text)
 #endif // HAVE_KF5
 
+#include <Preferences>
 #include "file.h"
-#include "preferences.h"
+#include "logging_data.h"
 
 quint64 ValueItem::internalIdCounter = 0;
 
@@ -90,9 +90,9 @@ QString Keyword::text() const
 
 void Keyword::replace(const QString &before, const QString &after, ValueItem::ReplaceMode replaceMode)
 {
-    if (replaceMode == ValueItem::AnySubstring)
+    if (replaceMode == ValueItem::ReplaceMode::AnySubstring)
         m_text = m_text.replace(before, after);
-    else if (replaceMode == ValueItem::CompleteMatch && m_text == before)
+    else if (replaceMode == ValueItem::ReplaceMode::CompleteMatch && m_text == before)
         m_text = after;
 }
 
@@ -145,11 +145,11 @@ QString Person::suffix() const
 
 void Person::replace(const QString &before, const QString &after, ValueItem::ReplaceMode replaceMode)
 {
-    if (replaceMode == ValueItem::AnySubstring) {
+    if (replaceMode == ValueItem::ReplaceMode::AnySubstring) {
         m_firstName = m_firstName.replace(before, after);
         m_lastName = m_lastName.replace(before, after);
         m_suffix = m_suffix.replace(before, after);
-    } else if (replaceMode == ValueItem::CompleteMatch) {
+    } else if (replaceMode == ValueItem::ReplaceMode::CompleteMatch) {
         if (m_firstName == before)
             m_firstName = after;
         if (m_lastName == before)
@@ -213,7 +213,7 @@ bool Person::isPerson(const ValueItem &other) {
 }
 
 QDebug operator<<(QDebug dbg, const Person &person) {
-    dbg.nospace() << "Person " << Person::transcribePersonName(&person, Preferences::defaultPersonNameFormatting);
+    dbg.nospace() << "Person " << Person::transcribePersonName(&person, Preferences::defaultPersonNameFormat);
     return dbg;
 }
 
@@ -250,9 +250,9 @@ bool MacroKey::isValid()
 
 void MacroKey::replace(const QString &before, const QString &after, ValueItem::ReplaceMode replaceMode)
 {
-    if (replaceMode == ValueItem::AnySubstring)
+    if (replaceMode == ValueItem::ReplaceMode::AnySubstring)
         m_text = m_text.replace(before, after);
-    else if (replaceMode == ValueItem::CompleteMatch && m_text == before)
+    else if (replaceMode == ValueItem::ReplaceMode::CompleteMatch && m_text == before)
         m_text = after;
 }
 
@@ -305,9 +305,9 @@ QString PlainText::text() const
 
 void PlainText::replace(const QString &before, const QString &after, ValueItem::ReplaceMode replaceMode)
 {
-    if (replaceMode == ValueItem::AnySubstring)
+    if (replaceMode == ValueItem::ReplaceMode::AnySubstring)
         m_text = m_text.replace(before, after);
-    else if (replaceMode == ValueItem::CompleteMatch && m_text == before)
+    else if (replaceMode == ValueItem::ReplaceMode::CompleteMatch && m_text == before)
         m_text = after;
 }
 
@@ -336,11 +336,6 @@ QDebug operator<<(QDebug dbg, const PlainText &plainText) {
 }
 
 
-#ifdef HAVE_KF5
-bool VerbatimText::colorLabelPairsInitialized = false;
-QList<VerbatimText::ColorLabelPair> VerbatimText::colorLabelPairs = QList<VerbatimText::ColorLabelPair>();
-#endif // HAVE_KF5
-
 VerbatimText::VerbatimText(const VerbatimText &other)
         : m_text(other.text())
 {
@@ -365,9 +360,9 @@ QString VerbatimText::text() const
 
 void VerbatimText::replace(const QString &before, const QString &after, ValueItem::ReplaceMode replaceMode)
 {
-    if (replaceMode == ValueItem::AnySubstring)
+    if (replaceMode == ValueItem::ReplaceMode::AnySubstring)
         m_text = m_text.replace(before, after);
-    else if (replaceMode == ValueItem::CompleteMatch && m_text == before)
+    else if (replaceMode == ValueItem::ReplaceMode::CompleteMatch && m_text == before)
         m_text = after;
 }
 
@@ -375,40 +370,14 @@ bool VerbatimText::containsPattern(const QString &pattern, Qt::CaseSensitivity c
 {
     const QString text = QString(m_text).remove(ignoredInSorting);
 
-#ifdef HAVE_KF5
-    /// Initialize map of labels to color (hex string) only once
-    // FIXME if user changes colors/labels later, it will not be updated here
-    if (!colorLabelPairsInitialized) {
-        colorLabelPairsInitialized = true;
-
-        /// Read data from config file
-        KSharedConfigPtr config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc")));
-        KConfigGroup configGroup(config, Preferences::groupColor);
-        const QStringList colorCodes = configGroup.readEntry(Preferences::keyColorCodes, Preferences::defaultColorCodes);
-        const QStringList colorLabels = configGroup.readEntry(Preferences::keyColorLabels, Preferences::defaultColorLabels);
-
-        /// Translate data from config file into internal mapping
-        for (QStringList::ConstIterator itc = colorCodes.constBegin(), itl = colorLabels.constBegin(); itc != colorCodes.constEnd() && itl != colorLabels.constEnd(); ++itc, ++itl) {
-            ColorLabelPair clp;
-            clp.hexColor = *itc;
-            clp.label = i18n((*itl).toUtf8().constData());
-            colorLabelPairs << clp;
-        }
-    }
-#endif //  HAVE_KF5
-
     bool contained = text.contains(pattern, caseSensitive);
-#ifdef HAVE_KF5
     if (!contained) {
         /// Only if simple text match failed, check color labels
         /// For a match, the user's pattern has to be the start of the color label
         /// and this verbatim text has to contain the color as hex string
-        for (const auto &clp : const_cast<const QList<ColorLabelPair> &>(colorLabelPairs)) {
-            contained = text.compare(clp.hexColor, Qt::CaseInsensitive) == 0 && clp.label.contains(pattern, Qt::CaseInsensitive);
-            if (contained) break;
-        }
+        for (QVector<QPair<QColor, QString>>::ConstIterator it = Preferences::instance().colorCodes().constBegin(); !contained && it != Preferences::instance().colorCodes().constEnd(); ++it)
+            contained = text.compare(it->first.name(), Qt::CaseInsensitive) == 0 && it->second.contains(pattern, Qt::CaseInsensitive);
     }
-#endif // HAVE_KF5
 
     return contained;
 }
@@ -631,19 +600,19 @@ QDebug operator<<(QDebug dbg, const Value &value) {
 
 QString PlainTextValue::text(const Value &value)
 {
-    ValueItemType vit = VITOther;
-    ValueItemType lastVit = VITOther;
+    ValueItemType vit = ValueItemType::Other;
+    ValueItemType lastVit = ValueItemType::Other;
 
     QString result;
     for (const auto &valueItem : value) {
         QString nextText = text(*valueItem, vit);
         if (!nextText.isEmpty()) {
-            if (lastVit == VITPerson && vit == VITPerson)
+            if (lastVit == ValueItemType::Person && vit == ValueItemType::Person)
                 result.append(i18n(" and ")); // TODO proper list of authors/editors, not just joined by "and"
-            else if (lastVit == VITPerson && vit == VITOther && nextText == QStringLiteral("others")) {
+            else if (lastVit == ValueItemType::Person && vit == ValueItemType::Other && nextText == QStringLiteral("others")) {
                 /// "and others" case: replace text to be appended by translated variant
                 nextText = i18n(" and others");
-            } else if (lastVit == VITKeyword && vit == VITKeyword)
+            } else if (lastVit == ValueItemType::Keyword && vit == ValueItemType::Keyword)
                 result.append("; ");
             else if (!result.isEmpty())
                 result.append(" ");
@@ -670,15 +639,7 @@ QString PlainTextValue::text(const ValueItem &valueItem)
 QString PlainTextValue::text(const ValueItem &valueItem, ValueItemType &vit)
 {
     QString result;
-    vit = VITOther;
-
-#ifdef HAVE_KF5
-    /// Required to have static instance of PlainTextValue here
-    /// to initialize @see personNameFormatting from settings
-    /// as well as update @see personNameFormatting upon notification
-    /// from NotificationHub
-    static PlainTextValue ptv;
-#endif // HAVE_KF5
+    vit = ValueItemType::Other;
 
     bool isVerbatim = false;
     const PlainText *plainText = dynamic_cast<const PlainText *>(&valueItem);
@@ -691,20 +652,20 @@ QString PlainTextValue::text(const ValueItem &valueItem, ValueItemType &vit)
         } else {
             const Person *person = dynamic_cast<const Person *>(&valueItem);
             if (person != nullptr) {
-                result = Person::transcribePersonName(person, personNameFormatting);
-                vit = VITPerson;
+                result = Person::transcribePersonName(person, Preferences::instance().personNameFormat());
+                vit = ValueItemType::Person;
             } else {
                 const Keyword *keyword = dynamic_cast<const Keyword *>(&valueItem);
                 if (keyword != nullptr) {
                     result = keyword->text();
-                    vit = VITKeyword;
+                    vit = ValueItemType::Keyword;
                 } else {
                     const VerbatimText *verbatimText = dynamic_cast<const VerbatimText *>(&valueItem);
                     if (verbatimText != nullptr) {
                         result = verbatimText->text();
                         isVerbatim = true;
                     } else
-                        qWarning() << "Cannot interpret ValueItem to one of its descendants";
+                        qCWarning(LOG_KBIBTEX_DATA) << "Cannot interpret ValueItem to one of its descendants";
                 }
             }
         }
@@ -715,7 +676,7 @@ QString PlainTextValue::text(const ValueItem &valueItem, ValueItemType &vit)
     int j = 0;
     static const QChar cbo = QLatin1Char('{'), cbc = QLatin1Char('}'), bs = QLatin1Char('\\'), mns = QLatin1Char('-'), comma = QLatin1Char(','), thinspace = QChar(0x2009), tilde = QLatin1Char('~'), nobreakspace = QChar(0x00a0);
     for (int i = 0; i < len; ++i) {
-        if ((result[i] == cbo || result[i] == cbc) && (i < 1 || result[qMax(i - 1, 0)] != bs)) {
+        if ((result[i] == cbo || result[i] == cbc) && (i < 1 || result[i - 1] != bs)) {
             /// hop over curly brackets
         } else if (i < len - 1 && result[i] == bs && result[i + 1] == mns) {
             /// hop over hyphenation commands
@@ -742,28 +703,3 @@ QString PlainTextValue::text(const ValueItem &valueItem, ValueItemType &vit)
 
     return result;
 }
-
-#ifdef HAVE_KF5
-PlainTextValue::PlainTextValue()
-{
-    NotificationHub::registerNotificationListener(this, NotificationHub::EventConfigurationChanged);
-    readConfiguration();
-}
-
-void PlainTextValue::notificationEvent(int eventId)
-{
-    if (eventId == NotificationHub::EventConfigurationChanged)
-        readConfiguration();
-}
-
-void PlainTextValue::readConfiguration()
-{
-    KSharedConfigPtr config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc")));
-    KConfigGroup configGroup(config, "General");
-    personNameFormatting = configGroup.readEntry(Preferences::keyPersonNameFormatting, Preferences::defaultPersonNameFormatting);
-}
-
-QString PlainTextValue::personNameFormatting;
-#else // HAVE_KF5
-const QString PlainTextValue::personNameFormatting = QStringLiteral("<%l><, %s><, %f>");
-#endif // HAVE_KF5
