@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,8 +15,8 @@
  *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
-#ifndef BIBTEXVALUE_H
-#define BIBTEXVALUE_H
+#ifndef KBIBTEX_DATA_VALUE_H
+#define KBIBTEX_DATA_VALUE_H
 
 #include <QVector>
 #include <QVariant>
@@ -26,10 +26,6 @@
 #include "kbibtexdata_export.h"
 #endif // HAVE_KF5
 
-#ifdef HAVE_KF5
-#include "notificationhub.h"
-#endif // HAVE_KF5
-
 class File;
 
 /**
@@ -39,7 +35,7 @@ class File;
 class KBIBTEXDATA_EXPORT ValueItem
 {
 public:
-    enum ReplaceMode {CompleteMatch, AnySubstring};
+    enum class ReplaceMode {CompleteMatch, AnySubstring};
 
     ValueItem();
     virtual ~ValueItem();
@@ -281,34 +277,18 @@ QDebug operator<<(QDebug dbg, const Value &value);
 
 
 class KBIBTEXDATA_EXPORT PlainTextValue
-#ifdef HAVE_KF5
-  : private NotificationListener
-#endif // HAVE_KF5
 {
 public:
     static QString text(const Value &value);
     static QString text(const ValueItem &valueItem);
     static QString text(const QSharedPointer<const ValueItem> &valueItem);
 
-#ifdef HAVE_KF5
-    void notificationEvent(int eventId) override;
-#endif // HAVE_KF5
-
 private:
-    enum ValueItemType { VITOther = 0, VITPerson, VITKeyword};
-
-#ifdef HAVE_KF5
-    PlainTextValue();
-    void readConfiguration();
-    static QString personNameFormatting;
-#else // HAVE_KF5
-    static const QString personNameFormatting;
-#endif // HAVE_KF5
+    enum class ValueItemType { Other = 0, Person, Keyword};
 
     static QString text(const ValueItem &valueItem, ValueItemType &vit);
-
 };
 
 Q_DECLARE_METATYPE(Value)
 
-#endif
+#endif // KBIBTEX_DATA_VALUE_H
