@@ -35,22 +35,21 @@
 #include <KSharedConfig>
 #include <KConfigGroup>
 
-#include "menulineedit.h"
-#include "entry.h"
-#include "comment.h"
-#include "macro.h"
-#include "preamble.h"
-#include "element.h"
-#include "file.h"
+#include <NotificationHub>
+#include <Entry>
+#include <Comment>
+#include <Macro>
+#include <Preamble>
+#include <Element>
+#include <File>
+#include <CheckBibTeX>
 #include "elementwidgets.h"
-#include "checkbibtex.h"
-#include "hidingtabwidget.h"
+#include "widgets/hidingtabwidget.h"
+#include "widgets/menulineedit.h"
 
 class ElementEditor::ElementEditorPrivate : public ElementEditor::ApplyElementInterface
 {
 private:
-    typedef QVector<ElementWidget *> WidgetList;
-    WidgetList widgets;
     const File *file;
     QSharedPointer<Entry> internalEntry;
     QSharedPointer<Macro> internalMacro;
@@ -59,7 +58,6 @@ private:
     ElementEditor *p;
     ElementWidget *previousWidget;
     ReferenceWidget *referenceWidget;
-    SourceWidget *sourceWidget;
     QPushButton *buttonCheckWithBibTeX;
 
     /// Settings management through a push button with menu
@@ -68,8 +66,12 @@ private:
     QAction *actionForceShowAllWidgets, *actionLimitKeyboardTabStops;
 
 public:
+    typedef QVector<ElementWidget *> WidgetList;
     QSharedPointer<Element> element;
     HidingTabWidget *tab;
+    WidgetList widgets;
+    SourceWidget *sourceWidget;
+    FilesWidget *filesWidget;
     bool elementChanged, elementUnapplied;
 
     ElementEditorPrivate(bool scrollable, ElementEditor *parent)
@@ -103,8 +105,9 @@ public:
 
     void addTabWidgets() {
         for (const auto &etl : EntryLayout::instance()) {
-            ElementWidget *widget = new EntryConfiguredWidget(etl, tab);
+            EntryConfiguredWidget *widget = new EntryConfiguredWidget(etl, tab);
             connect(widget, &ElementWidget::modified, p, &ElementEditor::childModified);
+            connect(widget, &EntryConfiguredWidget::requestingTabChange, p, &ElementEditor::switchToTab);
             widgets << widget;
             if (previousWidget == nullptr)
                 previousWidget = widget; ///< memorize the first tab
@@ -124,7 +127,7 @@ public:
         index = tab->addTab(widget, widget->icon(), widget->label());
         tab->hideTab(index);
 
-        FilesWidget *filesWidget = new FilesWidget(tab);
+        filesWidget = new FilesWidget(tab);
         connect(filesWidget, &FilesWidget::modified, p, &ElementEditor::childModified);
         widgets << filesWidget;
         index = tab->addTab(filesWidget, filesWidget->icon(), filesWidget->label());
@@ -168,7 +171,9 @@ public:
         referenceWidget = new ReferenceWidget(p);
         referenceWidget->setApplyElementInterface(this);
         connect(referenceWidget, &ElementWidget::modified, p, &ElementEditor::childModified);
-        connect(referenceWidget, &ReferenceWidget::entryTypeChanged, p, &ElementEditor::updateReqOptWidgets);
+        connect(referenceWidget, &ReferenceWidget::entryTypeChanged, p, [this]() {
+            updateReqOptWidgets();
+        });
         vLayout->addWidget(referenceWidget, 0);
         widgets << referenceWidget;
 
@@ -196,12 +201,16 @@ public:
         buttonOptions->setMenu(menuOptions);
 
         /// Option to show all fields or only those require for current entry type
-        actionForceShowAllWidgets = menuOptions->addAction(i18n("Show all fields"), p, SLOT(updateReqOptWidgets()));
+        actionForceShowAllWidgets = menuOptions->addAction(i18n("Show all fields"), p, [this]() {
+            updateReqOptWidgets();
+        });
         actionForceShowAllWidgets->setCheckable(true);
         actionForceShowAllWidgets->setChecked(showAll);
 
         /// Option to disable tab key focus to reach/visit various non-editable widgets
-        actionLimitKeyboardTabStops = menuOptions->addAction(i18n("Tab key visits only editable fields"), p, SLOT(limitKeyboardTabStops()));
+        actionLimitKeyboardTabStops = menuOptions->addAction(i18n("Tab key visits only editable fields"), p, [this]() {
+            this->limitKeyboardTabStops(); /// naming conflict between local variable 'limitKeyboardTabStops' and function 'limitKeyboardTabStops'
+        });
         actionLimitKeyboardTabStops->setCheckable(true);
         actionLimitKeyboardTabStops->setChecked(limitKeyboardTabStops);
 
@@ -209,13 +218,16 @@ public:
 
         buttonCheckWithBibTeX = new QPushButton(QIcon::fromTheme(QStringLiteral("tools-check-spelling")), i18n("Check with BibTeX"), p);
         hLayout->addWidget(buttonCheckWithBibTeX, 0);
-        connect(buttonCheckWithBibTeX, &QPushButton::clicked, p, &ElementEditor::checkBibTeX);
+        connect(buttonCheckWithBibTeX, &QPushButton::clicked, p, [this]() {
+            checkBibTeX();
+        });
 
         addTabWidgets();
     }
 
     void updateTabVisibility() {
-        disconnect(tab, &HidingTabWidget::currentChanged, p, &ElementEditor::tabChanged);
+        const QSignalBlocker blocker(tab);
+
         if (element.isNull()) {
             p->setEnabled(false);
         } else {
@@ -240,7 +252,6 @@ public:
             if (firstEnabledTab < 1024)
                 tab->setCurrentIndex(firstEnabledTab);
         }
-        connect(tab, &HidingTabWidget::currentChanged, p, &ElementEditor::tabChanged);
     }
 
     /**
@@ -289,15 +300,15 @@ public:
             /// Very simple if source view is active: BibTeX code contains
             /// all necessary data
             if (!e.isNull())
-                sourceWidget->setElementClass(SourceWidget::elementEntry);
+                sourceWidget->setElementClass(SourceWidget::ElementClass::Entry);
             else if (!m.isNull())
-                sourceWidget->setElementClass(SourceWidget::elementMacro);
+                sourceWidget->setElementClass(SourceWidget::ElementClass::Macro);
             else if (!p.isNull())
-                sourceWidget->setElementClass(SourceWidget::elementPreamble);
+                sourceWidget->setElementClass(SourceWidget::ElementClass::Preamble);
             else if (!c.isNull())
-                sourceWidget->setElementClass(SourceWidget::elementComment);
+                sourceWidget->setElementClass(SourceWidget::ElementClass::Comment);
             else
-                sourceWidget->setElementClass(SourceWidget::elementInvalid);
+                sourceWidget->setElementClass(SourceWidget::ElementClass::Invalid);
             sourceWidget->apply(element);
         } else {
             /// Start by assigning the current internal element's
@@ -369,22 +380,22 @@ public:
         QSharedPointer<const Entry> e = element.dynamicCast<const Entry>();
         if (!e.isNull()) {
             internalEntry = QSharedPointer<Entry>(new Entry(*e.data()));
-            sourceWidget->setElementClass(SourceWidget::elementEntry);
+            sourceWidget->setElementClass(SourceWidget::ElementClass::Entry);
         } else {
             QSharedPointer<const Macro> m = element.dynamicCast<const Macro>();
             if (!m.isNull()) {
                 internalMacro = QSharedPointer<Macro>(new Macro(*m.data()));
-                sourceWidget->setElementClass(SourceWidget::elementMacro);
+                sourceWidget->setElementClass(SourceWidget::ElementClass::Macro);
             } else {
                 QSharedPointer<const Comment> c = element.dynamicCast<const Comment>();
                 if (!c.isNull()) {
                     internalComment = QSharedPointer<Comment>(new Comment(*c.data()));
-                    sourceWidget->setElementClass(SourceWidget::elementComment);
+                    sourceWidget->setElementClass(SourceWidget::ElementClass::Comment);
                 } else {
                     QSharedPointer<const Preamble> p = element.dynamicCast<const Preamble>();
                     if (!p.isNull()) {
                         internalPreamble = QSharedPointer<Preamble>(new Preamble(*p.data()));
-                        sourceWidget->setElementClass(SourceWidget::elementPreamble);
+                        sourceWidget->setElementClass(SourceWidget::ElementClass::Preamble);
                     } else
                         Q_ASSERT_X(element.isNull(), "ElementEditor::ElementEditorPrivate::reset(QSharedPointer<const Element> element)", "element is not NULL but could not be cast on a valid Element sub-class");
                 }
@@ -655,9 +666,21 @@ void ElementEditor::tabChanged()
     d->switchTo(d->tab->currentWidget());
 }
 
-void ElementEditor::checkBibTeX()
+void ElementEditor::switchToTab(const QString &tabIdentifier)
 {
-    d->checkBibTeX();
+    if (tabIdentifier == QStringLiteral("source"))
+        setCurrentPage(d->sourceWidget);
+    else if (tabIdentifier == QStringLiteral("external"))
+        setCurrentPage(d->filesWidget);
+    else {
+        for (ElementWidget *widget : const_cast<const ElementEditor::ElementEditorPrivate::WidgetList &>(d->widgets)) {
+            EntryConfiguredWidget *ecw = qobject_cast<EntryConfiguredWidget *>(widget);
+            if (ecw != nullptr && ecw->identifier() == tabIdentifier) {
+                setCurrentPage(ecw);
+                break;
+            }
+        }
+    }
 }
 
 void ElementEditor::childModified(bool m)
@@ -668,13 +691,3 @@ void ElementEditor::childModified(bool m)
     }
     emit modified(m);
 }
-
-void ElementEditor::updateReqOptWidgets()
-{
-    d->updateReqOptWidgets();
-}
-
-void ElementEditor::limitKeyboardTabStops()
-{
-    d->limitKeyboardTabStops();
-}
