@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,24 +18,24 @@
 #ifndef KBIBTEX_GUI_ELEMENTWIDGETS_H
 #define KBIBTEX_GUI_ELEMENTWIDGETS_H
 
-#include "kbibtexgui_export.h"
-
 #include <QLabel>
 #include <QWidget>
 #include <QUrl>
 #include <QIcon>
 
-#include "elementeditor.h"
-#include "entrylayout.h"
-#include "fileimporter.h"
+#include <FileImporter>
+#include <element/ElementEditor>
+#include <config/EntryLayout>
+
+#include "kbibtexgui_export.h"
 
 class QTreeWidget;
 class QTreeWidgetItem;
+class QBoxLayout;
 class QGridLayout;
 class QPushButton;
-
-class KLineEdit;
-class KComboBox;
+class QLineEdit;
+class QComboBox;
 
 namespace KTextEditor {
 class Document;
@@ -96,6 +96,7 @@ private:
     } LabeledFieldInput;
     LabeledFieldInput **listOfLabeledFieldInput;
     const int fieldInputCount, numCols;
+    QBoxLayout *vboxLayout;
     QGridLayout *gridLayout;
 
     const QSharedPointer<const EntryTabLayout> etl;
@@ -113,12 +114,19 @@ public:
     bool validate(QWidget **widgetWithIssue, QString &message) const override;
     void setReadOnly(bool isReadOnly) override;
     void showReqOptWidgets(bool forceVisible, const QString &entryType) override;
+    QString identifier() const;
     QString label() override;
     QIcon icon() override;
 
     void setFile(const File *file) override;
 
     bool canEdit(const Element *element) override;
+
+signals:
+    void requestingTabChange(const QString &tabIdentifier);
+
+private slots:
+    void infoMessageLinkActivated(const QString &contents);
 };
 
 class ReferenceWidget : public ElementWidget
@@ -126,8 +134,8 @@ class ReferenceWidget : public ElementWidget
     Q_OBJECT
 
 private:
-    KComboBox *entryType;
-    KLineEdit *entryId;
+    QComboBox *entryType;
+    QLineEdit *entryId;
     QPushButton *buttonSuggestId;
 
     void createGUI();
@@ -210,7 +218,7 @@ class OtherFieldsWidget : public ElementWidget
     Q_OBJECT
 
 private:
-    KLineEdit *fieldName;
+    QLineEdit *fieldName;
     FieldInput *fieldContent;
     QTreeWidget *otherFieldsList;
     QPushButton *buttonDelete;
@@ -300,7 +308,7 @@ class SourceWidget : public ElementWidget
     Q_OBJECT
 
 public:
-    enum ElementClass { elementInvalid = -1, elementEntry = 0, elementMacro, elementPreamble, elementComment };
+    enum class ElementClass { Invalid = -1, Entry = 0, Macro, Preamble, Comment };
 
 private:
     KTextEditor::Document *document;
