@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2023 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -239,7 +239,7 @@ void PDFItemDelegate::slotViewPDF()
         const QUrl url = index.data(PDFListModel::URLRole).toUrl();
         if (!tempfileName.isEmpty()) {
             /// Guess mime type for url to open
-            QUrl tempUrl(tempfileName);
+            QUrl tempUrl{QUrl::fromLocalFile(tempfileName)};
             QMimeType mimeType = FileInfo::mimeTypeForUrl(tempUrl);
             const QString mimeTypeName = mimeType.name();
             /// Ask KDE subsystem to open url in viewer matching mime type
@@ -431,7 +431,7 @@ FindPDFUI::~FindPDFUI()
     }
 }
 
-void FindPDFUI::interactiveFindPDF(Entry &entry, const File &bibtexFile, QWidget *parent)
+bool FindPDFUI::interactiveFindPDF(Entry &entry, const File &bibtexFile, QWidget *parent)
 {
     QPointer<QDialog> dlg = new QDialog(parent);
     QPointer<FindPDFUI> widget = new FindPDFUI(entry, dlg);
@@ -450,12 +450,15 @@ void FindPDFUI::interactiveFindPDF(Entry &entry, const File &bibtexFile, QWidget
     connect(buttonBox->button(QDialogButtonBox::Abort), &QPushButton::clicked, widget.data(), &FindPDFUI::stopSearch);
 
     if (dlg->exec() == QDialog::Accepted)
-        widget->apply(entry, bibtexFile);
-    delete dlg;
+        return widget->apply(entry, bibtexFile);
+    else
+        return false;
 }
 
-void FindPDFUI::apply(Entry &entry, const File &bibtexFile)
+bool FindPDFUI::apply(Entry &entry, const File &bibtexFile)
 {
+    bool bibtexFileModified = false;
+
     QAbstractItemModel *model = d->listViewResult->model();
     for (int i = 0; i < model->rowCount(); ++i) {
         bool ok = false;
@@ -476,13 +479,15 @@ void FindPDFUI::apply(Entry &entry, const File &bibtexFile)
             if (!alreadyContained) {
                 Value value;
                 value.append(QSharedPointer<VerbatimText>(new VerbatimText(url.toDisplayString())));
-                if (!entry.contains(Entry::ftUrl))
+                if (!entry.contains(Entry::ftUrl)) {
                     entry.insert(Entry::ftUrl, value);
-                else
+                    bibtexFileModified = true;
+                } else
                     for (int i = 2; i < 256; ++i) {
                         const QString keyName = QString(QStringLiteral("%1%2")).arg(Entry::ftUrl).arg(i);
                         if (!entry.contains(keyName)) {
                             entry.insert(keyName, value);
+                            bibtexFileModified = true;
                             break;
                         }
                     }
@@ -504,13 +509,15 @@ void FindPDFUI::apply(Entry &entry, const File &bibtexFile)
                     Value value;
                     value.append(QSharedPointer<VerbatimText>(new VerbatimText(visibleFilename)));
                     const QString fieldNameStem = Preferences::instance().bibliographySystem() == Preferences::BibliographySystem::BibTeX ? Entry::ftLocalFile : Entry::ftFile;
-                    if (!entry.contains(fieldNameStem))
+                    if (!entry.contains(fieldNameStem)) {
                         entry.insert(fieldNameStem, value);
-                    else
+                        bibtexFileModified = true;
+                    } else
                         for (int i = 2; i < 256; ++i) {
                             const QString keyName = QString(QStringLiteral("%1%2")).arg(fieldNameStem).arg(i);
                             if (!entry.contains(keyName)) {
                                 entry.insert(keyName, value);
+                                bibtexFileModified = true;
                                 break;
                             }
                         }
@@ -518,6 +525,8 @@ void FindPDFUI::apply(Entry &entry, const File &bibtexFile)
             }
         }
     }
+
+    return bibtexFileModified;
 }
 
 void FindPDFUI::searchFinished()
