@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "settingscolorlabelwidget.h"
@@ -22,65 +22,75 @@
 
 #include <QLayout>
 #include <QStyledItemDelegate>
-#include <QSignalMapper>
+#include <QPushButton>
+#include <QLineEdit>
+#include <QMenu>
+#if QT_VERSION >= 0x050a00
+#include <QRandomGenerator>
+#endif // QT_VERSION
 
-#include <KPushButton>
 #include <KColorButton>
-#include <KColorDialog>
-#include <KLineEdit>
 #include <KActionMenu>
-#include <KMenu>
+#include <KLocalizedString>
 
-#include "file.h"
-#include "fileview.h"
-#include "colorlabelwidget.h"
-#include "filemodel.h"
-#include "preferences.h"
+#include <Preferences>
+#include <File>
+#include <Entry>
+#include "file/fileview.h"
+#include "field/colorlabelwidget.h"
+
+#if QT_VERSION >= 0x050a00
+#define randomGeneratorGlobalBounded(min,max)  QRandomGenerator::global()->bounded((min),(max))
+#else // QT_VERSION
+#define randomGeneratorGlobalBounded(min,max)  ((min)+(qrand()%((max)-(min)+1)))
+#endif // QT_VERSION
 
 class ColorLabelSettingsDelegate : public QStyledItemDelegate
 {
+    Q_OBJECT
+
 public:
-    ColorLabelSettingsDelegate(QWidget *parent = NULL)
+    ColorLabelSettingsDelegate(QWidget *parent = nullptr)
             : QStyledItemDelegate(parent) {
         /// nothing
     }
 
-    virtual QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &index) const {
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &index) const override {
         if (index.column() == 0)
             /// Colors are to be edited in a color button
             return new KColorButton(parent);
         else
             /// Text strings are to be edited in a line edit
-            return new KLineEdit(parent);
+            return new QLineEdit(parent);
     }
 
-    void setEditorData(QWidget *editor, const QModelIndex &index) const {
+    void setEditorData(QWidget *editor, const QModelIndex &index) const override {
         if (index.column() == 0) {
             KColorButton *colorButton = qobject_cast<KColorButton *>(editor);
             /// Initialized color button with row's current color
             colorButton->setColor(index.model()->data(index, Qt::EditRole).value<QColor>());
         } else {
-            KLineEdit *lineEdit = qobject_cast<KLineEdit *>(editor);
+            QLineEdit *lineEdit = qobject_cast<QLineEdit *>(editor);
             /// Initialized line edit with row's current color's label
             lineEdit->setText(index.model()->data(index, Qt::EditRole).toString());
         }
     }
 
-    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const {
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override {
         if (index.column() == 0) {
             KColorButton *colorButton = qobject_cast<KColorButton *>(editor);
             if (colorButton->color() != Qt::black)
                 /// Assign color button's color back to model
                 model->setData(index, colorButton->color(), Qt::EditRole);
         } else if (index.column() == 1) {
-            KLineEdit *lineEdit = qobject_cast<KLineEdit *>(editor);
+            QLineEdit *lineEdit = qobject_cast<QLineEdit *>(editor);
             if (!lineEdit->text().isEmpty())
                 /// Assign line edit's text back to model
                 model->setData(index, lineEdit->text(), Qt::EditRole);
         }
     }
 
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const {
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override {
         QSize hint = QStyledItemDelegate::sizeHint(option, index);
         QFontMetrics fm = QFontMetrics(QFont());
         /// Enforce minimum height of 4 times x-height
@@ -91,7 +101,7 @@ public:
 
 
 ColorLabelSettingsModel::ColorLabelSettingsModel(QObject *parent)
-        : QAbstractItemModel(parent), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc")))
+        : QAbstractItemModel(parent)
 {
     /// Load stored color-label pairs
     loadState();
@@ -100,7 +110,7 @@ ColorLabelSettingsModel::ColorLabelSettingsModel(QObject *parent)
 int ColorLabelSettingsModel::rowCount(const QModelIndex &parent) const
 {
     /// Single-level list of color-label pairs has as many rows as pairs
-    return parent == QModelIndex() ? colorLabelPairs.count() : 0;
+    return parent == QModelIndex() ? colorLabelPairs.size() : 0;
 }
 
 int ColorLabelSettingsModel::columnCount(const QModelIndex &parent) const
@@ -112,9 +122,9 @@ int ColorLabelSettingsModel::columnCount(const QModelIndex &parent) const
 
 QModelIndex ColorLabelSettingsModel::index(int row, int column, const QModelIndex &parent) const
 {
-    if (row >= 0 && row <= colorLabelPairs.count() - 1 && column >= 0 && column <= 1 && parent == QModelIndex())
+    if (row >= 0 && row <= colorLabelPairs.size() - 1 && column >= 0 && column <= 1 && parent == QModelIndex())
         /// Create index for valid combinations of row, column, and parent
-        return createIndex(row, column, row);
+        return createIndex(row, column, static_cast<quintptr>(row));
     else
         return QModelIndex();
 }
@@ -128,15 +138,15 @@ QModelIndex ColorLabelSettingsModel::parent(const QModelIndex &) const
 QVariant ColorLabelSettingsModel::data(const QModelIndex &index, int role) const
 {
     /// Skip invalid model indices
-    if (index == QModelIndex() || index.row() < 0 || index.row() >= colorLabelPairs.count())
+    if (index == QModelIndex() || index.row() < 0 || index.row() >= colorLabelPairs.size())
         return QVariant();
 
     if ((role == Qt::DecorationRole || role == Qt::EditRole) && index.column() == 0)
         /// First column has colors only (no text)
-        return colorLabelPairs[index.row()].color;
+        return colorLabelPairs[index.row()].first;
     else if ((role == Qt::DisplayRole || role == Qt::EditRole) && index.column() == 1)
         /// Second column has colors' labels
-        return colorLabelPairs[index.row()].label;
+        return colorLabelPairs[index.row()].second;
 
     return QVariant();
 }
@@ -151,7 +161,7 @@ bool ColorLabelSettingsModel::setData(const QModelIndex &index, const QVariant &
             const QColor color = value.value<QColor>();
             if (color != Qt::black && (color.red() > 0 || color.green() > 0 || color.blue() > 0)) {
                 /// ... store this color in the data structure
-                colorLabelPairs[index.row()].color = color;
+                colorLabelPairs[index.row()].first = color;
                 /// Notify everyone about the changes
                 emit dataChanged(left, right);
                 emit modified();
@@ -162,7 +172,7 @@ bool ColorLabelSettingsModel::setData(const QModelIndex &index, const QVariant &
             const QString text = value.toString();
             if (!text.isEmpty()) {
                 /// ... store this text in the data structure
-                colorLabelPairs[index.row()].label = text;
+                colorLabelPairs[index.row()].second = text;
                 /// Notify everyone about the changes
                 emit dataChanged(left, right);
                 emit modified();
@@ -199,34 +209,23 @@ QVariant ColorLabelSettingsModel::headerData(int section, Qt::Orientation orient
  */
 void ColorLabelSettingsModel::loadState()
 {
-    KConfigGroup configGroup(config, Preferences::groupColor);
-    QStringList colorCodes = configGroup.readEntry(Preferences::keyColorCodes, Preferences::defaultColorCodes);
-    QStringList colorLabels = configGroup.readEntry(Preferences::keyColorLabels, Preferences::defaultcolorLabels);
-
-    colorLabelPairs.clear();
-    for (QStringList::ConstIterator itc = colorCodes.constBegin(), itl = colorLabels.constBegin(); itc != colorCodes.constEnd() && itl != colorLabels.constEnd(); ++itc, ++itl) {
-        ColorLabelPair clp;
-        clp.color = QColor(*itc);
-        clp.label = i18n((*itl).toUtf8().constData());
-        colorLabelPairs << clp;
-    }
+    colorLabelPairs = Preferences::instance().colorCodes();
 }
 
 /**
  * Save list of color-label pairs in user's configuration file.
  */
-void ColorLabelSettingsModel::saveState()
+bool ColorLabelSettingsModel::saveState()
 {
-    QStringList colorCodes, colorLabels;
-    foreach (const ColorLabelPair &clp, colorLabelPairs) {
-        colorCodes << clp.color.name();
-        colorLabels << clp.label;
-    }
+    const QVector<QPair<QColor, QString>> oldColorCodes = Preferences::instance().colorCodes();
+    Preferences::instance().setColorCodes(colorLabelPairs);
 
-    KConfigGroup configGroup(config, Preferences::groupColor);
-    configGroup.writeEntry(Preferences::keyColorCodes, colorCodes);
-    configGroup.writeEntry(Preferences::keyColorLabels, colorLabels);
-    config->sync();
+    QVector<QPair<QColor, QString>>::ConstIterator itOld = oldColorCodes.constBegin();
+    QVector<QPair<QColor, QString>>::ConstIterator itNew = colorLabelPairs.constBegin();
+    for (; itOld != oldColorCodes.constEnd() && itNew != colorLabelPairs.constEnd(); ++itOld, ++itNew)
+        if (itOld->first != itNew->first || itOld->second != itNew->second)
+            return true;
+    return !(itOld == oldColorCodes.constEnd() && itNew == colorLabelPairs.constEnd());
 }
 
 /**
@@ -235,13 +234,7 @@ void ColorLabelSettingsModel::saveState()
  */
 void ColorLabelSettingsModel::resetToDefaults()
 {
-    colorLabelPairs.clear();
-    for (QStringList::ConstIterator itc = Preferences::defaultColorCodes.constBegin(), itl = Preferences::defaultcolorLabels.constBegin(); itc != Preferences::defaultColorCodes.constEnd() && itl != Preferences::defaultcolorLabels.constEnd(); ++itc, ++itl) {
-        ColorLabelPair clp;
-        clp.color = QColor(*itc);
-        clp.label = i18n((*itl).toUtf8().constData());
-        colorLabelPairs << clp;
-    }
+    colorLabelPairs = Preferences::instance().defaultColorCodes;
     emit modified();
 }
 
@@ -257,10 +250,7 @@ void ColorLabelSettingsModel::addColorLabel(const QColor &color, const QString &
 {
     const int newRow = colorLabelPairs.size();
     beginInsertRows(QModelIndex(), newRow, newRow);
-    ColorLabelPair clp;
-    clp.color = color;
-    clp.label = label;
-    colorLabelPairs << clp;
+    colorLabelPairs.append(qMakePair(color, label));
     endInsertRows();
 
     emit modified();
@@ -274,7 +264,7 @@ void ColorLabelSettingsModel::addColorLabel(const QColor &color, const QString &
  */
 void ColorLabelSettingsModel::removeColorLabel(int row)
 {
-    if (row >= 0 && row < colorLabelPairs.count()) {
+    if (row >= 0 && row < colorLabelPairs.size()) {
         beginRemoveRows(QModelIndex(), row, row);
         colorLabelPairs.removeAt(row);
         endRemoveRows();
@@ -289,34 +279,34 @@ private:
     SettingsColorLabelWidget *p;
     ColorLabelSettingsDelegate *delegate;
 
-    KSharedConfigPtr config;
-
 public:
     ColorLabelSettingsModel *model;
-    KPushButton *buttonRemove;
+    QPushButton *buttonRemove;
     QTreeView *view;
 
     Private(SettingsColorLabelWidget *parent)
-            : p(parent), delegate(NULL), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))),
-          model(NULL), buttonRemove(NULL), view(NULL) {
+            : p(parent), delegate(nullptr), model(nullptr), buttonRemove(nullptr), view(nullptr)
+    {
         /// nothing
     }
 
     void loadState() {
         /// Delegate state maintenance to model
-        if (model != NULL)
+        if (model != nullptr)
             model->loadState();
     }
 
-    void saveState() {
+    bool saveState() {
         /// Delegate state maintenance to model
-        if (model != NULL)
-            model->saveState();
+        if (model != nullptr)
+            return model->saveState();
+        else
+            return false;
     }
 
     void resetToDefaults() {
         /// Delegate state maintenance to model
-        if (model != NULL)
+        if (model != nullptr)
             model->resetToDefaults();
     }
 
@@ -335,24 +325,24 @@ public:
         view->setModel(model);
         /// Changes in the model (e.g. through setData(..))
         /// get propagated as this widget's changed() signal
-        connect(model, SIGNAL(modified()), p, SIGNAL(changed()));
+        connect(model, &ColorLabelSettingsModel::modified, p, &SettingsColorLabelWidget::changed);
 
         /// Delegate to handle changes of color (through KColorButton)
-        /// and label (throuh KLineEdit)
+        /// and label (throuh QLineEdit)
         delegate = new ColorLabelSettingsDelegate(view);
         view->setItemDelegate(delegate);
 
         /// Button to add a new randomized color
-        KPushButton *buttonAdd = new KPushButton(KIcon("list-add"), i18n("Add..."), p);
+        QPushButton *buttonAdd = new QPushButton(QIcon::fromTheme(QStringLiteral("list-add")), i18n("Add..."), p);
         layout->addWidget(buttonAdd, 0, 1, 1, 1);
-        connect(buttonAdd, SIGNAL(clicked()), p, SLOT(addColor()));
+        connect(buttonAdd, &QPushButton::clicked, p, &SettingsColorLabelWidget::addColor);
 
         /// Remove selected color-label pair; button is disabled
         /// if no row is selected in tree view
-        buttonRemove = new KPushButton(KIcon("list-remove"), i18n("Remove"), p);
+        buttonRemove = new QPushButton(QIcon::fromTheme(QStringLiteral("list-remove")), i18n("Remove"), p);
         layout->addWidget(buttonRemove, 1, 1, 1, 1);
         buttonRemove->setEnabled(false);
-        connect(buttonRemove, SIGNAL(clicked()), p, SLOT(removeColor()));
+        connect(buttonRemove, &QPushButton::clicked, p, &SettingsColorLabelWidget::removeColor);
     }
 };
 
@@ -360,13 +350,10 @@ public:
 SettingsColorLabelWidget::SettingsColorLabelWidget(QWidget *parent)
         : SettingsAbstractWidget(parent), d(new Private(this))
 {
-    /// Seed random number generator
-    qsrand(time(NULL));
-
     /// Setup GUI elements
     d->setupGUI();
     /// Connect signals
-    connect(d->view->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(updateRemoveButtonStatus()));
+    connect(d->view->selectionModel(), &QItemSelectionModel::selectionChanged, this, &SettingsColorLabelWidget::updateRemoveButtonStatus);
 }
 
 SettingsColorLabelWidget::~SettingsColorLabelWidget()
@@ -379,9 +366,9 @@ QString SettingsColorLabelWidget::label() const
     return i18n("Color & Labels");
 }
 
-KIcon SettingsColorLabelWidget::icon() const
+QIcon SettingsColorLabelWidget::icon() const
 {
-    return KIcon("preferences-desktop-color");
+    return QIcon::fromTheme(QStringLiteral("preferences-desktop-color"));
 }
 
 void SettingsColorLabelWidget::loadState()
@@ -389,9 +376,9 @@ void SettingsColorLabelWidget::loadState()
     d->loadState();
 }
 
-void SettingsColorLabelWidget::saveState()
+bool SettingsColorLabelWidget::saveState()
 {
-    d->saveState();
+    return d->saveState();
 }
 
 void SettingsColorLabelWidget::resetToDefaults()
@@ -403,7 +390,7 @@ void SettingsColorLabelWidget::addColor()
 {
     /// Create a randomized color, but guarantee
     /// some minimum value for each color component
-    const QColor newColor((qrand() & 0xff) | 0x30, (qrand() & 0xff) | 0x30, (qrand() & 0xff) | 0x30);
+    const QColor newColor(randomGeneratorGlobalBounded(0, 0xff) | 0x30, randomGeneratorGlobalBounded(0, 0xff) | 0x30, randomGeneratorGlobalBounded(0, 0xff) | 0x30);
     /// Set the new label to be the color's hex string
     const QString newColorName(newColor.name().remove(QLatin1Char('#')));
     /// Add new color-label pair to model's data
@@ -431,21 +418,18 @@ void SettingsColorLabelWidget::updateRemoveButtonStatus()
 class ColorLabelContextMenu::Private
 {
 private:
-    // UNUSED ColorLabelContextMenu *p;
+    ColorLabelContextMenu *p;
 
 public:
     /// Tree view to show this context menu in
     FileView *fileView;
     /// Actual menu to show
     KActionMenu *menu;
-    /// Signal handle to react to calls to items in menu
-    QSignalMapper *sm;
 
     Private(FileView *fv, ColorLabelContextMenu *parent)
-        : /* UNUSED p(parent),*/ fileView(fv)
+            : p(parent), fileView(fv)
     {
-        sm = new QSignalMapper(parent);
-        menu = new KActionMenu(KIcon("preferences-desktop-color"), i18n("Color"), fileView);
+        menu = new KActionMenu(QIcon::fromTheme(QStringLiteral("preferences-desktop-color")), i18n("Color"), fileView);
         /// Let menu be a sub menu to the tree view's context menu
         fileView->addAction(menu);
     }
@@ -455,27 +439,70 @@ public:
 
         /// Add color-label pairs to menu as stored
         /// in the user's configuration file
-        KSharedConfigPtr config(KSharedConfig::openConfig(QLatin1String("kbibtexrc")));
-        KConfigGroup configGroup(config, Preferences::groupColor);
-        QStringList colorCodes = configGroup.readEntry(Preferences::keyColorCodes, Preferences::defaultColorCodes);
-        QStringList colorLabels = configGroup.readEntry(Preferences::keyColorLabels, Preferences::defaultcolorLabels);
-        for (QStringList::ConstIterator itc = colorCodes.constBegin(), itl = colorLabels.constBegin(); itc != colorCodes.constEnd() && itl != colorLabels.constEnd(); ++itc, ++itl) {
-            KAction *action = new KAction(KIcon(ColorLabelWidget::createSolidIcon(*itc)), i18n((*itl).toUtf8().constData()), menu);
+        for (QVector<QPair<QColor, QString>>::ConstIterator it = Preferences::instance().colorCodes().constBegin(); it != Preferences::instance().colorCodes().constEnd(); ++it) {
+            QAction *action = new QAction(QIcon(ColorLabelWidget::createSolidIcon(it->first)), it->second, menu);
             menu->addAction(action);
-            sm->setMapping(action, *itc);
-            connect(action, SIGNAL(triggered()), sm, SLOT(map()));
+            const QString colorCode = it->first.name();
+            connect(action, &QAction::triggered, p, [this, colorCode]() {
+                colorActivated(colorCode);
+            });
         }
 
-        KAction *action = new KAction(menu);
+        QAction *action = new QAction(menu);
         action->setSeparator(true);
         menu->addAction(action);
 
         /// Special action that removes any color
         /// from a BibTeX entry by setting the color to black
-        action = new KAction(i18n("No color"), menu);
+        action = new QAction(i18n("No color"), menu);
         menu->addAction(action);
-        sm->setMapping(action, QLatin1String("#000000"));
-        connect(action, SIGNAL(triggered()), sm, SLOT(map()));
+        connect(action, &QAction::triggered, p, [this]() {
+            colorActivated(QStringLiteral("#000000"));
+        });
+    }
+
+
+    void colorActivated(const QString &colorString)
+    {
+        /// User activated some color from the menu, so apply this color
+        /// code to the currently selected item in the tree view
+
+        SortFilterFileModel *sfbfm = qobject_cast<SortFilterFileModel *>(fileView->model());
+        if (sfbfm == nullptr) {
+            /// Something went horribly wrong
+            return;
+        }
+        FileModel *model = sfbfm->fileSourceModel();
+        if (model == nullptr) {
+            /// Something went horribly wrong
+            return;
+        }
+
+        /// Apply color change to all selected rows
+        const QModelIndexList list = fileView->selectionModel()->selectedIndexes();
+        for (const QModelIndex &index : list) {
+            const QModelIndex mappedIndex = sfbfm->mapToSource(index);
+            /// Selection may span over multiple columns;
+            /// to avoid duplicate assignments, consider only column 1
+            if (mappedIndex.column() == 1) {
+                const int row = mappedIndex.row();
+                QSharedPointer<Entry> entry = model->element(row).dynamicCast<Entry>();
+                if (!entry.isNull()) {
+                    /// Clear old color entry
+                    bool modifying = entry->remove(Entry::ftColor) > 0;
+                    if (colorString != QStringLiteral("#000000")) { ///< black is a special color that means "no color"
+                        /// Only if valid color was selected, set this color
+                        Value v;
+                        v.append(QSharedPointer<VerbatimText>(new VerbatimText(colorString)));
+                        entry->insert(Entry::ftColor, v);
+                        modifying = true;
+                    }
+                    if (modifying)
+                        // TODO notification of modification does not propagate?
+                        model->elementChanged(row);
+                }
+            }
+        }
     }
 };
 
@@ -483,8 +510,6 @@ public:
 ColorLabelContextMenu::ColorLabelContextMenu(FileView *widget)
         : QObject(widget), d(new Private(widget, this))
 {
-    connect(d->sm, SIGNAL(mapped(QString)), this, SLOT(colorActivated(QString)));
-
     /// Listen to changes in the configuration files
     NotificationHub::registerNotificationListener(this, NotificationHub::EventConfigurationChanged);
 
@@ -511,44 +536,4 @@ void ColorLabelContextMenu::notificationEvent(int eventId)
         d->rebuildMenu();
 }
 
-void ColorLabelContextMenu::colorActivated(const QString &colorString)
-{
-    /// User activated some color from the menu,
-    /// so apply this color code to the currently
-    /// selected item in the tree view
-
-    SortFilterFileModel *sfbfm = qobject_cast<SortFilterFileModel *>(d->fileView->model());
-    Q_ASSERT_X(sfbfm != NULL, "ColorLabelContextMenu::colorActivated(const QString &colorString)", "SortFilterFileModel *sfbfm is NULL");
-    FileModel *model = sfbfm->fileSourceModel();
-    Q_ASSERT_X(model != NULL, "ColorLabelContextMenu::colorActivated(const QString &colorString)", "FileModel *model is NULL");
-    File *file = model->bibliographyFile();
-    Q_ASSERT_X(file != NULL, "ColorLabelContextMenu::colorActivated(const QString &colorString)", "File *file is NULL");
-
-    /// Keep track if any changes to the bibliography is made
-    bool modifying = false;
-    /// Apply color change to all selected rows
-    QModelIndexList list = d->fileView->selectionModel()->selectedIndexes();
-    foreach (const QModelIndex &index, list) {
-        const QModelIndex mappedIndex = sfbfm->mapToSource(index);
-        /// Selection may span over multiple columns;
-        /// to avoid duplicate assignments, consider only column 1
-        if (mappedIndex.column() == 1) {
-            QSharedPointer<Entry> entry = file->at(mappedIndex.row()).dynamicCast<Entry>();
-            if (!entry.isNull()) {
-                /// Clear old color entry
-                modifying |= entry->remove(Entry::ftColor) > 0;
-                if (colorString != QLatin1String("#000000")) { ///< black is a special color that means "no color"
-                    /// Only if valid color was selected, set this color
-                    Value v;
-                    v.append(QSharedPointer<VerbatimText>(new VerbatimText(colorString)));
-                    entry->insert(Entry::ftColor, v);
-                    modifying = true;
-                }
-            }
-        }
-    }
-
-    if (modifying)
-        /// Let the FileView widget know that its underlying data model has been changed
-        d->fileView->externalModification();
-}
+#include "settingscolorlabelwidget.moc"
