@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,15 +12,15 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifndef KBIBTEX_GUI_SETTINGSFILEEXPORTERPDFPSWIDGET_H
 #define KBIBTEX_GUI_SETTINGSFILEEXPORTERPDFPSWIDGET_H
 
-#include <kbibtexgui_export.h>
+#include <preferences/SettingsAbstractWidget>
 
-#include "settingsabstractwidget.h"
+#include "kbibtexgui_export.h"
 
 /**
  * @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
@@ -31,15 +31,15 @@ class KBIBTEXGUI_EXPORT SettingsFileExporterPDFPSWidget : public SettingsAbstrac
 
 public:
     explicit SettingsFileExporterPDFPSWidget(QWidget *parent);
-    ~SettingsFileExporterPDFPSWidget();
+    ~SettingsFileExporterPDFPSWidget() override;
 
-    virtual QString label() const;
-    virtual KIcon icon() const;
+    QString label() const override;
+    QIcon icon() const override;
 
 public slots:
-    void loadState();
-    void saveState();
-    void resetToDefaults();
+    void loadState() override;
+    bool saveState() override;
+    void resetToDefaults() override;
 
 private:
     class SettingsFileExporterPDFPSWidgetPrivate;
