@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,78 +18,67 @@
 #include "settingsgeneralwidget.h"
 
 #include <QFormLayout>
+#include <QComboBox>
 
 #include <KLocalizedString>
-#include <KSharedConfig>
-#include <KConfigGroup>
-#include <KComboBox>
 
-#include "guihelper.h"
-#include "value.h"
 #include "preferences.h"
+#include "value.h"
+#include "guihelper.h"
 
 class SettingsGeneralWidget::SettingsGeneralWidgetPrivate
 {
 private:
     SettingsGeneralWidget *p;
 
-    KComboBox *comboBoxBibliographySystem;
-    KComboBox *comboBoxPersonNameFormatting;
+    QComboBox *comboBoxBibliographySystem;
+    QComboBox *comboBoxPersonNameFormatting;
     const Person dummyPerson;
-    QString restartRequiredMsg;
-
-    KSharedConfigPtr config;
-    const QString configGroupName;
 
 public:
 
     SettingsGeneralWidgetPrivate(SettingsGeneralWidget *parent)
-            : p(parent), dummyPerson(Person(i18n("John"), i18n("Doe"), i18n("Jr."))), restartRequiredMsg(i18n("Changing this option requires a restart to take effect.")), config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc"))), configGroupName(QStringLiteral("General")) {
+            : p(parent), dummyPerson(Person(i18n("John"), i18n("Doe"), i18n("Jr."))) {
         setupGUI();
     }
 
     void loadState() {
-        comboBoxBibliographySystem->setCurrentIndex(comboBoxBibliographySystem->findData(QVariant::fromValue<int>(static_cast<int>(Preferences::bibliographySystem()))));
+        comboBoxBibliographySystem->setCurrentIndex(comboBoxBibliographySystem->findData(QVariant::fromValue<int>(static_cast<int>(Preferences::instance().bibliographySystem()))));
 
-        KConfigGroup configGroup(config, configGroupName);
-        QString personNameFormatting = configGroup.readEntry(Preferences::keyPersonNameFormatting, Preferences::defaultPersonNameFormatting);
-        int row = GUIHelper::selectValue(comboBoxPersonNameFormatting->model(), Person::transcribePersonName(&dummyPerson, personNameFormatting));
+        int row = GUIHelper::selectValue(comboBoxPersonNameFormatting->model(), Person::transcribePersonName(&dummyPerson, Preferences::instance().personNameFormat()));
         comboBoxPersonNameFormatting->setCurrentIndex(row);
     }
 
-    void saveState() {
-        Preferences::setBibliographySystem(static_cast<Preferences::BibliographySystem>(comboBoxBibliographySystem->currentData().toInt()));
-
-        KConfigGroup configGroup(config, configGroupName);
-        configGroup.writeEntry(Preferences::keyPersonNameFormatting, comboBoxPersonNameFormatting->itemData(comboBoxPersonNameFormatting->currentIndex()));
-        config->sync();
+    bool saveState() {
+        bool settingsGotChanged = false;
+        settingsGotChanged |= Preferences::instance().setBibliographySystem(static_cast<Preferences::BibliographySystem>(comboBoxBibliographySystem->currentData().toInt()));
+        settingsGotChanged |= Preferences::instance().setPersonNameFormat(comboBoxPersonNameFormatting->itemData(comboBoxPersonNameFormatting->currentIndex()).toString());
+        return settingsGotChanged;
     }
 
     void resetToDefaults() {
         comboBoxBibliographySystem->setCurrentIndex(static_cast<int>(Preferences::defaultBibliographySystem));
 
-        int row = GUIHelper::selectValue(comboBoxPersonNameFormatting->model(), Person::transcribePersonName(&dummyPerson, Preferences::defaultPersonNameFormatting));
+        int row = GUIHelper::selectValue(comboBoxPersonNameFormatting->model(), Person::transcribePersonName(&dummyPerson, Preferences::defaultPersonNameFormat));
         comboBoxPersonNameFormatting->setCurrentIndex(row);
     }
 
     void setupGUI() {
         QFormLayout *layout = new QFormLayout(p);
 
-        comboBoxBibliographySystem = new KComboBox(false, p);
+        comboBoxBibliographySystem = new QComboBox(p);
         comboBoxBibliographySystem->setObjectName(QStringLiteral("comboBoxBibliographySystem"));
-        const QMap<Preferences::BibliographySystem, QString> &availableBibliographySystems = Preferences::availableBibliographySystems();
-        for (QMap<Preferences::BibliographySystem, QString>::ConstIterator it = availableBibliographySystems.constBegin(), itEnd = availableBibliographySystems.constEnd(); it != itEnd; ++it)
-            comboBoxBibliographySystem->addItem(it.value(), QVariant::fromValue<int>(static_cast<int>(it.key())));
+
+        for (QVector<QPair<Preferences::BibliographySystem, QString>>::ConstIterator it = Preferences::availableBibliographySystems.constBegin(); it != Preferences::availableBibliographySystems.constEnd(); ++it)
+            comboBoxBibliographySystem->addItem(it->second, QVariant::fromValue<int>(static_cast<int>(it->first)));
         layout->addRow(i18n("Bibliography System:"), comboBoxBibliographySystem);
         connect(comboBoxBibliographySystem, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), p, &SettingsGeneralWidget::changed);
 
-        comboBoxPersonNameFormatting = new KComboBox(false, p);
+        comboBoxPersonNameFormatting = new QComboBox(p);
         layout->addRow(i18n("Person Names Formatting:"), comboBoxPersonNameFormatting);
-        const QStringList formattingOptions {Preferences::personNameFormatFirstLast, Preferences::personNameFormatLastFirst};
-        for (const QString &formattingOption : formattingOptions) {
+        static const QStringList formattingOptions {Preferences::personNameFormatFirstLast, Preferences::personNameFormatLastFirst};
+        for (const QString &formattingOption : formattingOptions)
             comboBoxPersonNameFormatting->addItem(Person::transcribePersonName(&dummyPerson, formattingOption), formattingOption);
-        }
-        comboBoxPersonNameFormatting->setToolTip(restartRequiredMsg);
         connect(comboBoxPersonNameFormatting, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), p, &SettingsGeneralWidget::changed);
     }
 };
@@ -121,9 +110,9 @@ void SettingsGeneralWidget::loadState()
     d->loadState();
 }
 
-void SettingsGeneralWidget::saveState()
+bool SettingsGeneralWidget::saveState()
 {
-    d->saveState();
+    return d->saveState();
 }
 
 void SettingsGeneralWidget::resetToDefaults()
