@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,25 +23,23 @@
 #include <QTextDocument>
 #include <QAbstractTextDocumentLayout>
 #include <QListView>
+#include <QLineEdit>
 #include <QGridLayout>
 #include <QStringListModel>
 #include <QPainter>
 #include <QFrame>
 #include <QLayout>
 #include <QHeaderView>
+#include <QComboBox>
 
-#include <KComboBox>
 #include <KLocalizedString>
-#include <KSharedConfig>
-#include <KConfigGroup>
 #include <KColorScheme>
-#include <KLineEdit>
 
-#include "fieldlineedit.h"
-#include "bibtexfields.h"
-#include "entry.h"
-#include "preferences.h"
-#include "models/filemodel.h"
+#include <BibTeXFields>
+#include <Preferences>
+#include <Entry>
+#include <models/FileModel>
+#include "field/fieldlineedit.h"
 #include "logging_gui.h"
 
 QWidget *ValueListDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &sovi, const QModelIndex &index) const
@@ -84,7 +82,7 @@ QSize ValueListDelegate::sizeHint(const QStyleOptionViewItem &option, const QMod
 
 void ValueListDelegate::commitAndCloseEditor()
 {
-    KLineEdit *editor = qobject_cast<KLineEdit *>(sender());
+    QLineEdit *editor = qobject_cast<QLineEdit *>(sender());
     emit commitData(editor);
     emit closeEditor(editor);
 }
@@ -132,9 +130,14 @@ void ValueListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &_op
 
     /// squeeze the folder text if it is to big and calculate the rectangles
     /// where the folder text and the unread count will be drawn to
-    QFontMetrics fm(painter->fontMetrics());
-    int countWidth = fm.width(count);
+    const QFontMetrics fm(painter->fontMetrics());
+#if QT_VERSION >= 0x050b00
+    const int countWidth = fm.horizontalAdvance(count);
+    int fieldWidth = fm.horizontalAdvance(field);
+#else // QT_VERSION >= 0x050b00
+    const int countWidth = fm.width(count);
     int fieldWidth = fm.width(field);
+#endif // QT_VERSION >= 0x050b00
     if (countWidth + fieldWidth > textRect.width()) {
         /// text plus count is too wide for column, cut text and insert "..."
         field = fm.elidedText(field, Qt::ElideRight, textRect.width() - countWidth - 8);
@@ -184,7 +187,7 @@ void ValueListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &_op
 }
 
 ValueListModel::ValueListModel(const File *bibtexFile, const QString &fieldName, QObject *parent)
-        : QAbstractTableModel(parent), file(bibtexFile), fName(fieldName.toLower()), showCountColumn(true), sortBy(SortByText)
+        : QAbstractTableModel(parent), file(bibtexFile), fName(fieldName.toLower()), showCountColumn(true), sortBy(SortBy::Text)
 {
     readConfiguration();
     updateValues();
@@ -223,7 +226,7 @@ QVariant ValueListModel::data(const QModelIndex &index, int role) const
         QString buffer = values[index.row()].sortBy.isEmpty() ? values[index.row()].text : values[index.row()].sortBy;
         buffer = buffer.remove(ignoredInSorting).toLower();
 
-        if ((showCountColumn && index.column() == 1) || (!showCountColumn && sortBy == SortByCount)) {
+        if ((showCountColumn && index.column() == 1) || (!showCountColumn && sortBy == SortBy::Count)) {
             /// Sort by string consisting of a zero-padded count and the lower-case text,
             /// for example "0000000051keyword"
             /// Used if (a) two columns are shown (showCountColumn is true) and column 1
@@ -292,7 +295,7 @@ QVariant ValueListModel::headerData(int section, Qt::Orientation orientation, in
 {
     if (section >= 2 || orientation != Qt::Horizontal || role != Qt::DisplayRole)
         return QVariant();
-    else if ((section == 0 && columnCount() == 2) || (columnCount() == 1 && sortBy == SortByText))
+    else if ((section == 0 && columnCount() == 2) || (columnCount() == 1 && sortBy == SortBy::Text))
         return QVariant(i18n("Value"));
     else
         return QVariant(i18n("Count"));
@@ -330,14 +333,9 @@ void ValueListModel::notificationEvent(int eventId)
 void ValueListModel::readConfiguration()
 {
     /// load mapping from color value to label
-    KSharedConfigPtr config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc")));
-    KConfigGroup configGroup(config, Preferences::groupColor);
-    QStringList colorCodes = configGroup.readEntry(Preferences::keyColorCodes, Preferences::defaultColorCodes);
-    QStringList colorLabels = configGroup.readEntry(Preferences::keyColorLabels, Preferences::defaultColorLabels);
     colorToLabel.clear();
-    for (QStringList::ConstIterator itc = colorCodes.constBegin(), itl = colorLabels.constBegin(); itc != colorCodes.constEnd() && itl != colorLabels.constEnd(); ++itc, ++itl) {
-        colorToLabel.insert(*itc, i18n((*itl).toUtf8().constData()));
-    }
+    for (QVector<QPair<QColor, QString>>::ConstIterator it = Preferences::instance().colorCodes().constBegin(); it != Preferences::instance().colorCodes().constEnd(); ++it)
+        colorToLabel.insert(it->first.name(), it->second);
 }
 
 void ValueListModel::updateValues()
