@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,14 +23,12 @@
 #include <QTextStream>
 #include <QDir>
 
-#include <KSharedConfig>
-#include <KConfigGroup>
-
+#include <KBibTeX>
+#include <Preferences>
+#include <Element>
+#include <Entry>
 #include "fileinfo.h"
-#include "element.h"
-#include "entry.h"
 #include "fileexporterbibtex.h"
-#include "kbibtex.h"
 #include "logging_io.h"
 
 FileExporterPDF::FileExporterPDF(QObject *parent)
@@ -39,9 +37,7 @@ FileExporterPDF::FileExporterPDF(QObject *parent)
     m_fileBasename = QStringLiteral("bibtex-to-pdf");
     m_fileStem = tempDir.path() + QDir::separator() + m_fileBasename;
 
-    setFileEmbedding(FileExporterPDF::EmbedBibTeXFileAndReferences);
-
-    reloadConfig();
+    setFileEmbedding(FileExporterPDF::FileEmbedding::BibTeXFileAndReferences);
 }
 
 FileExporterPDF::~FileExporterPDF()
@@ -49,17 +45,6 @@ FileExporterPDF::~FileExporterPDF()
     /// nothing
 }
 
-void FileExporterPDF::reloadConfig()
-{
-    KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("kbibtexrc"));
-    KConfigGroup configGroup(config, QStringLiteral("FileExporterPDFPS"));
-    m_babelLanguage = configGroup.readEntry(keyBabelLanguage, defaultBabelLanguage);
-    m_bibliographyStyle = configGroup.readEntry(keyBibliographyStyle, defaultBibliographyStyle);
-
-    KConfigGroup configGroupGeneral(config, QStringLiteral("General"));
-    m_paperSize = configGroupGeneral.readEntry(keyPaperSize, defaultPaperSize);
-}
-
 bool FileExporterPDF::save(QIODevice *iodevice, const File *bibtexfile, QStringList *errorLog)
 {
     if (!iodevice->isWritable() && !iodevice->open(QIODevice::WriteOnly)) {
@@ -69,9 +54,9 @@ bool FileExporterPDF::save(QIODevice *iodevice, const File *bibtexfile, QStringL
 
     bool result = false;
     m_embeddedFileList.clear();
-    if (m_fileEmbedding & EmbedBibTeXFile)
+    if (m_fileEmbeddings.testFlag(FileEmbedding::BibTeXFile))
         m_embeddedFileList.append(QString(QStringLiteral("%1|%2|%3")).arg(QStringLiteral("BibTeX source"), m_fileStem + KBibTeX::extensionBibTeX, m_fileBasename + KBibTeX::extensionBibTeX));
-    if (m_fileEmbedding & EmbedReferences)
+    if (m_fileEmbeddings.testFlag(FileEmbedding::References))
         fillEmbeddedFileList(bibtexfile);
 
     QFile output(m_fileStem + KBibTeX::extensionBibTeX);
@@ -124,13 +109,13 @@ void FileExporterPDF::setDocumentSearchPaths(const QStringList &searchPaths)
     m_searchPaths = searchPaths;
 }
 
-void FileExporterPDF::setFileEmbedding(FileEmbedding fileEmbedding) {
+void FileExporterPDF::setFileEmbedding(const FileEmbeddings fileEmbedding) {
     /// If there is not embedfile.sty file, disable embedding
     /// irrespective of user's wishes
     if (!kpsewhich(QStringLiteral("embedfile.sty")))
-        m_fileEmbedding = NoFileEmbedding;
+        m_fileEmbeddings = FileEmbedding::None;
     else
-        m_fileEmbedding = fileEmbedding;
+        m_fileEmbeddings = fileEmbedding;
 }
 
 bool FileExporterPDF::generatePDF(QIODevice *iodevice, QStringList *errorLog)
@@ -146,25 +131,65 @@ bool FileExporterPDF::writeLatexFile(const QString &filename)
     if (latexFile.open(QIODevice::WriteOnly)) {
         QTextStream ts(&latexFile);
         ts.setCodec("UTF-8");
+#if QT_VERSION >= 0x050e00
+        ts << "\\documentclass{article}" << Qt::endl;
+        ts << "\\usepackage[T1]{fontenc}" << Qt::endl;
+        ts << "\\usepackage[utf8]{inputenc}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
         ts << "\\documentclass{article}" << endl;
         ts << "\\usepackage[T1]{fontenc}" << endl;
         ts << "\\usepackage[utf8]{inputenc}" << endl;
+#endif // QT_VERSION >= 0x050e00
         if (kpsewhich(QStringLiteral("babel.sty")))
-            ts << "\\usepackage[" << m_babelLanguage << "]{babel}" << endl;
+#if QT_VERSION >= 0x050e00
+            ts << "\\usepackage[" << Preferences::instance().laTeXBabelLanguage() << "]{babel}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
+            ts << "\\usepackage[" << Preferences::instance().laTeXBabelLanguage() << "]{babel}" << endl;
+#endif // QT_VERSION >= 0x050e00
         if (kpsewhich(QStringLiteral("hyperref.sty")))
+#if QT_VERSION >= 0x050e00
+            ts << "\\usepackage[pdfborder={0 0 0},pdfproducer={KBibTeX: https://userbase.kde.org/KBibTeX},pdftex]{hyperref}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
             ts << "\\usepackage[pdfborder={0 0 0},pdfproducer={KBibTeX: https://userbase.kde.org/KBibTeX},pdftex]{hyperref}" << endl;
+#endif // QT_VERSION >= 0x050e00
         else if (kpsewhich(QStringLiteral("url.sty")))
+#if QT_VERSION >= 0x050e00
+            ts << "\\usepackage{url}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
             ts << "\\usepackage{url}" << endl;
-        if (m_bibliographyStyle.startsWith(QStringLiteral("apacite")) && kpsewhich(QStringLiteral("apacite.sty")))
+#endif // QT_VERSION >= 0x050e00
+        const QString bibliographyStyle = Preferences::instance().bibTeXBibliographyStyle();
+        if (bibliographyStyle.startsWith(QStringLiteral("apacite")) && kpsewhich(QStringLiteral("apacite.sty")))
+#if QT_VERSION >= 0x050e00
+            ts << "\\usepackage[bibnewpage]{apacite}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
             ts << "\\usepackage[bibnewpage]{apacite}" << endl;
-        if ((m_bibliographyStyle == QStringLiteral("agsm") || m_bibliographyStyle == QStringLiteral("dcu") || m_bibliographyStyle == QStringLiteral("jmr") || m_bibliographyStyle == QStringLiteral("jphysicsB") || m_bibliographyStyle == QStringLiteral("kluwer") || m_bibliographyStyle == QStringLiteral("nederlands") || m_bibliographyStyle == QStringLiteral("dcu") || m_bibliographyStyle == QStringLiteral("dcu")) && kpsewhich(QStringLiteral("harvard.sty")) && kpsewhich(QStringLiteral("html.sty")))
+#endif // QT_VERSION >= 0x050e00
+        if ((bibliographyStyle == QStringLiteral("agsm") || bibliographyStyle == QStringLiteral("dcu") || bibliographyStyle == QStringLiteral("jmr") || bibliographyStyle == QStringLiteral("jphysicsB") || bibliographyStyle == QStringLiteral("kluwer") || bibliographyStyle == QStringLiteral("nederlands") || bibliographyStyle == QStringLiteral("dcu") || bibliographyStyle == QStringLiteral("dcu")) && kpsewhich(QStringLiteral("harvard.sty")) && kpsewhich(QStringLiteral("html.sty")))
+#if QT_VERSION >= 0x050e00
+            ts << "\\usepackage{html}" << Qt::endl << "\\usepackage[dcucite]{harvard}" << Qt::endl << "\\renewcommand{\\harvardurl}{URL: \\url}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
             ts << "\\usepackage{html}" << endl << "\\usepackage[dcucite]{harvard}" << endl << "\\renewcommand{\\harvardurl}{URL: \\url}" << endl;
+#endif // QT_VERSION >= 0x050e00
         if (kpsewhich(QStringLiteral("embedfile.sty")))
+#if QT_VERSION >= 0x050e00
+            ts << "\\usepackage{embedfile}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
             ts << "\\usepackage{embedfile}" << endl;
+#endif // QT_VERSION >= 0x050e00
         if (kpsewhich(QStringLiteral("geometry.sty")))
-            ts << "\\usepackage[paper=" << m_paperSize << (m_paperSize.length() <= 2 ? "paper" : "") << "]{geometry}" << endl;
-        ts << "\\bibliographystyle{" << m_bibliographyStyle << "}" << endl;
+#if QT_VERSION >= 0x050e00
+            ts << "\\usepackage[paper=" << pageSizeToLaTeXName(Preferences::instance().pageSize()) << "]{geometry}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
+            ts << "\\usepackage[paper=" << pageSizeToLaTeXName(Preferences::instance().pageSize()) << "]{geometry}" << endl;
+#endif // QT_VERSION >= 0x050e00
+#if QT_VERSION >= 0x050e00
+        ts << "\\bibliographystyle{" << bibliographyStyle << "}" << Qt::endl;
+        ts << "\\begin{document}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
+        ts << "\\bibliographystyle{" << bibliographyStyle << "}" << endl;
         ts << "\\begin{document}" << endl;
+#endif // QT_VERSION >= 0x050e00
 
         if (!m_embeddedFileList.isEmpty())
             for (const QString &embeddedFile : const_cast<const QStringList &>(m_embeddedFileList)) {
@@ -177,12 +202,22 @@ bool FileExporterPDF::writeLatexFile(const QString &filename)
                     ts << ",mimetype={text/x-bibtex}";
                 else if (param[2].endsWith(KBibTeX::extensionPDF))
                     ts << ",mimetype={application/pdf}";
+#if QT_VERSION >= 0x050e00
+                ts << "]{" << param[1] << "}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
                 ts << "]{" << param[1] << "}" << endl;
+#endif // QT_VERSION >= 0x050e00
             }
 
+#if QT_VERSION >= 0x050e00
+        ts << "\\nocite{*}" << Qt::endl;
+        ts << QStringLiteral("\\bibliography{") << m_fileBasename << QStringLiteral("}") << Qt::endl;
+        ts << "\\end{document}" << Qt::endl;
+#else // QT_VERSION < 0x050e00
         ts << "\\nocite{*}" << endl;
         ts << QStringLiteral("\\bibliography{") << m_fileBasename << QStringLiteral("}") << endl;
         ts << "\\end{document}" << endl;
+#endif // QT_VERSION >= 0x050e00
         latexFile.close();
         return true;
     } else
@@ -205,7 +240,7 @@ void FileExporterPDF::fillEmbeddedFileList(const QSharedPointer<const Element> e
     const QSharedPointer<const Entry> entry = element.dynamicCast<const Entry>();
     if (!entry.isNull()) {
         const QString title = PlainTextValue::text(entry->value(Entry::ftTitle));
-        const auto urlList = FileInfo::entryUrls(entry, bibtexfile->property(File::Url).toUrl(), FileInfo::TestExistenceYes);
+        const auto urlList = FileInfo::entryUrls(entry, bibtexfile->property(File::Url).toUrl(), FileInfo::TestExistence::Yes);
         for (const QUrl &url : urlList) {
             if (!url.isLocalFile()) continue;
             const QString filename = url.toLocalFile();
