@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,11 +20,11 @@
 #include <QRegularExpression>
 #include <QStringList>
 
-#include "kbibtex.h"
-#include "file.h"
-#include "entry.h"
-#include "macro.h"
-#include "comment.h"
+#include <KBibTeX>
+#include <File>
+#include <Entry>
+#include <Macro>
+#include <Comment>
 #include "encoderxml.h"
 #include "logging_io.h"
 
@@ -53,15 +53,26 @@ bool FileExporterXML::save(QIODevice *iodevice, const File *bibtexfile, QStringL
     QTextStream stream(iodevice);
     stream.setCodec("UTF-8");
 
+#if QT_VERSION >= 0x050e00
+    stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << Qt::endl;
+    stream << "<!-- XML document written by KBibTeXIO as part of KBibTeX -->" << Qt::endl;
+    stream << "<!-- https://userbase.kde.org/KBibTeX -->" << Qt::endl;
+    stream << "<bibliography>" << Qt::endl;
+#else // QT_VERSION < 0x050e00
     stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
     stream << "<!-- XML document written by KBibTeXIO as part of KBibTeX -->" << endl;
     stream << "<!-- https://userbase.kde.org/KBibTeX -->" << endl;
     stream << "<bibliography>" << endl;
+#endif // QT_VERSION >= 0x050e00
 
     for (File::ConstIterator it = bibtexfile->constBegin(); it != bibtexfile->constEnd() && result && !m_cancelFlag; ++it)
-        write(stream, (*it).data(), bibtexfile);
+        result &= write(stream, (*it).data(), bibtexfile);
 
+#if QT_VERSION >= 0x050e00
+    stream << "</bibliography>" << Qt::endl;
+#else // QT_VERSION < 0x050e00
     stream << "</bibliography>" << endl;
+#endif // QT_VERSION >= 0x050e00
 
     iodevice->close();
     return result && !m_cancelFlag;
@@ -80,12 +91,26 @@ bool FileExporterXML::save(QIODevice *iodevice, const QSharedPointer<const Eleme
     QTextStream stream(iodevice);
     stream.setCodec("UTF-8");
 
+#if QT_VERSION >= 0x050e00
+    stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << Qt::endl;
+    stream << "<!-- XML document written by KBibTeXIO as part of KBibTeX -->" << Qt::endl;
+    stream << "<!-- https://userbase.kde.org/KBibTeX -->" << Qt::endl;
+    stream << "<bibliography>" << Qt::endl;
+#else // QT_VERSION < 0x050e00
     stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
     stream << "<!-- XML document written by KBibTeXIO as part of KBibTeX -->" << endl;
     stream << "<!-- https://userbase.kde.org/KBibTeX -->" << endl;
+    stream << "<bibliography>" << endl;
+#endif // QT_VERSION >= 0x050e00
 
     const bool result = write(stream, element.data());
 
+#if QT_VERSION >= 0x050e00
+    stream << "</bibliography>" << Qt::endl;
+#else // QT_VERSION < 0x050e00
+    stream << "</bibliography>" << endl;
+#endif // QT_VERSION >= 0x050e00
+
     iodevice->close();
     return result;
 }
@@ -126,7 +151,11 @@ bool FileExporterXML::write(QTextStream &stream, const Element *element, const F
 
 bool FileExporterXML::writeEntry(QTextStream &stream, const Entry *entry)
 {
-    stream << " <entry id=\"" << EncoderXML::instance().encode(entry->id(), Encoder::TargetEncodingUTF8) << "\" type=\"" << entry->type().toLower() << "\">" << endl;
+#if QT_VERSION >= 0x050e00
+    stream << " <entry id=\"" << EncoderXML::instance().encode(entry->id(), Encoder::TargetEncoding::UTF8) << "\" type=\"" << entry->type().toLower() << "\">" << Qt::endl;
+#else // QT_VERSION < 0x050e00
+    stream << " <entry id=\"" << EncoderXML::instance().encode(entry->id(), Encoder::TargetEncoding::UTF8) << "\" type=\"" << entry->type().toLower() << "\">" << endl;
+#endif // QT_VERSION >= 0x050e00
     for (Entry::ConstIterator it = entry->constBegin(); it != entry->constEnd(); ++it) {
         const QString key = it.key().toLower();
         const Value value = it.value();
@@ -145,15 +174,25 @@ bool FileExporterXML::writeEntry(QTextStream &stream, const Entry *entry)
                     stream << " etal=\"true\"";
                 }
             }
+#if QT_VERSION >= 0x050e00
+            stream << ">" << Qt::endl;
+            stream << valueToXML(internal, key) << Qt::endl;
+            stream << "  </" << key << "s>" << Qt::endl;
+#else // QT_VERSION < 0x050e00
             stream << ">" << endl;
             stream << valueToXML(internal, key) << endl;
             stream << "  </" << key << "s>" << endl;
+#endif // QT_VERSION >= 0x050e00
         } else if (key == Entry::ftAbstract) {
             static const QRegularExpression abstractRegExp(QStringLiteral("\\bAbstract[:]?([ ]|&nbsp;|&amp;nbsp;)*"), QRegularExpression::CaseInsensitiveOption);
             /// clean up HTML artifacts
             QString text = valueToXML(value);
             text = text.remove(abstractRegExp);
+#if QT_VERSION >= 0x050e00
+            stream << "  <" << key << ">" << text << "</" << key << ">" << Qt::endl;
+#else // QT_VERSION < 0x050e00
             stream << "  <" << key << ">" << text << "</" << key << ">" << endl;
+#endif // QT_VERSION >= 0x050e00
         } else if (key == Entry::ftMonth) {
             stream << "  <month";
             bool ok = false;
@@ -186,13 +225,25 @@ bool FileExporterXML::writeEntry(QTextStream &stream, const Entry *entry)
             if (month > 0)
                 stream << " month=\"" << month << "\"";
             stream << '>' << content;
+#if QT_VERSION >= 0x050e00
+            stream << "</month>" << Qt::endl;
+#else // QT_VERSION < 0x050e00
             stream << "</month>" << endl;
+#endif // QT_VERSION >= 0x050e00
         } else {
+#if QT_VERSION >= 0x050e00
+            stream << "  <" << key << ">" << valueToXML(value) << "</" << key << ">" << Qt::endl;
+#else // QT_VERSION < 0x050e00
             stream << "  <" << key << ">" << valueToXML(value) << "</" << key << ">" << endl;
+#endif // QT_VERSION >= 0x050e00
         }
 
     }
+#if QT_VERSION >= 0x050e00
+    stream << " </entry>" << Qt::endl;
+#else // QT_VERSION < 0x050e00
     stream << " </entry>" << endl;
+#endif // QT_VERSION >= 0x050e00
 
     return true;
 }
@@ -201,7 +252,11 @@ bool FileExporterXML::writeMacro(QTextStream &stream, const Macro *macro)
 {
     stream << " <string key=\"" << macro->key() << "\">";
     stream << valueToXML(macro->value());
+#if QT_VERSION >= 0x050e00
+    stream << "</string>" << Qt::endl;
+#else // QT_VERSION < 0x050e00
     stream << "</string>" << endl;
+#endif // QT_VERSION >= 0x050e00
 
     return true;
 }
@@ -209,8 +264,12 @@ bool FileExporterXML::writeMacro(QTextStream &stream, const Macro *macro)
 bool FileExporterXML::writeComment(QTextStream &stream, const Comment *comment)
 {
     stream << " <comment>" ;
-    stream << EncoderXML::instance().encode(comment->text(), Encoder::TargetEncodingUTF8);
+    stream << EncoderXML::instance().encode(comment->text(), Encoder::TargetEncoding::UTF8);
+#if QT_VERSION >= 0x050e00
+    stream << "</comment>" << Qt::endl;
+#else // QT_VERSION < 0x050e00
     stream << "</comment>" << endl;
+#endif // QT_VERSION >= 0x050e00
 
     return true;
 }
@@ -227,22 +286,22 @@ QString FileExporterXML::valueToXML(const Value &value, const QString &)
 
         QSharedPointer<const PlainText> plainText = valueItem.dynamicCast<const PlainText>();
         if (!plainText.isNull())
-            result.append("<text>" +  cleanXML(EncoderXML::instance().encode(PlainTextValue::text(valueItem), Encoder::TargetEncodingUTF8)) + "</text>");
+            result.append("<text>" +  cleanXML(EncoderXML::instance().encode(PlainTextValue::text(valueItem), Encoder::TargetEncoding::UTF8)) + "</text>");
         else {
             QSharedPointer<const Person> p = valueItem.dynamicCast<const Person>();
             if (!p.isNull()) {
                 result.append("<person>");
                 if (!p->firstName().isEmpty())
-                    result.append("<firstname>" +  cleanXML(EncoderXML::instance().encode(p->firstName(), Encoder::TargetEncodingUTF8)) + "</firstname>");
+                    result.append("<firstname>" +  cleanXML(EncoderXML::instance().encode(p->firstName(), Encoder::TargetEncoding::UTF8)) + "</firstname>");
                 if (!p->lastName().isEmpty())
-                    result.append("<lastname>" +  cleanXML(EncoderXML::instance().encode(p->lastName(), Encoder::TargetEncodingUTF8)) + "</lastname>");
+                    result.append("<lastname>" +  cleanXML(EncoderXML::instance().encode(p->lastName(), Encoder::TargetEncoding::UTF8)) + "</lastname>");
                 if (!p->suffix().isEmpty())
-                    result.append("<suffix>" +  cleanXML(EncoderXML::instance().encode(p->suffix(), Encoder::TargetEncodingUTF8)) + "</suffix>");
+                    result.append("<suffix>" +  cleanXML(EncoderXML::instance().encode(p->suffix(), Encoder::TargetEncoding::UTF8)) + "</suffix>");
                 result.append("</person>");
             }
             // TODO: Other data types
             else
-                result.append("<text>" + cleanXML(EncoderXML::instance().encode(PlainTextValue::text(valueItem), Encoder::TargetEncodingUTF8)) + "</text>");
+                result.append("<text>" + cleanXML(EncoderXML::instance().encode(PlainTextValue::text(valueItem), Encoder::TargetEncoding::UTF8)) + "</text>");
         }
     }
 
