@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,7 +22,7 @@
 #include <QStringList>
 #include <QRegularExpression>
 
-#include "value.h"
+#include <Value>
 #include "logging_io.h"
 
 FileImporter::FileImporter(QObject *parent)
@@ -59,6 +59,7 @@ File *FileImporter::fromString(const QString &text)
 
 Person *FileImporter::splitName(const QString &name)
 {
+    // TODO Merge with FileImporterBibTeX::personFromString and FileImporterBibTeX::contextSensitiveSplit
     QString firstName;
     QString lastName;
     QString suffix;
@@ -124,7 +125,7 @@ Person *FileImporter::splitName(const QString &name)
             firstName = segments[1].trimmed();
             suffix = segments[2].trimmed();
         } else
-            qWarning() << "Too many commas in name:" << name;
+            qCWarning(LOG_KBIBTEX_IO) << "Too many commas in name:" << name;
     }
 
     return new Person(firstName, lastName, suffix);
