@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,35 +18,35 @@
 #include "onlinesearchieeexplore.h"
 
 #include <QNetworkReply>
-#include <QStandardPaths>
 #include <QUrl>
 #include <QUrlQuery>
-#include <QCoreApplication>
 
 #ifdef HAVE_KF5
 #include <KLocalizedString>
+#else // HAVE_KF5
+#define i18n(text) QObject::tr(text)
 #endif // HAVE_KF5
 
+#include <XSLTransform>
+#include <EncoderXML>
+#include <FileImporterBibTeX>
 #include "internalnetworkaccessmanager.h"
-#include "xsltransform.h"
-#include "encoderxml.h"
-#include "fileimporterbibtex.h"
 #include "logging_networking.h"
 
 class OnlineSearchIEEEXplore::OnlineSearchIEEEXplorePrivate
 {
 private:
-    OnlineSearchIEEEXplore *p;
+    static const QString xsltFilenameBase;
 
 public:
     static const QUrl apiUrl;
     const XSLTransform xslt;
 
-    OnlineSearchIEEEXplorePrivate(OnlineSearchIEEEXplore *parent)
-            : p(parent),
-              xslt(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QCoreApplication::instance()->applicationName().remove(QStringLiteral("test")) + QStringLiteral("/ieeexploreapiv1-to-bibtex.xsl")))
+    OnlineSearchIEEEXplorePrivate(OnlineSearchIEEEXplore *)
+            : xslt(XSLTransform::locateXSLTfile(xsltFilenameBase))
     {
-        /// nothing
+        if (!xslt.isValid())
+            qCWarning(LOG_KBIBTEX_NETWORKING) << "Failed to initialize XSL transformation based on file '" << xsltFilenameBase << "'";
     }
 
     QUrl buildQueryUrl(const QMap<QString, QString> &query, int numResults) {
@@ -54,17 +54,17 @@ public:
         QUrlQuery q(queryUrl.query());
 
         /// Free text
-        const QStringList freeTextFragments = p->splitRespectingQuotationMarks(query[queryKeyFreeText]);
+        const QStringList freeTextFragments = OnlineSearchAbstract::splitRespectingQuotationMarks(query[queryKeyFreeText]);
         if (!freeTextFragments.isEmpty())
             q.addQueryItem(QStringLiteral("querytext"), QStringLiteral("\"") + freeTextFragments.join(QStringLiteral("\"+\"")) + QStringLiteral("\""));
 
         /// Title
-        const QStringList title = p->splitRespectingQuotationMarks(query[queryKeyTitle]);
+        const QStringList title = OnlineSearchAbstract::splitRespectingQuotationMarks(query[queryKeyTitle]);
         if (!title.isEmpty())
             q.addQueryItem(QStringLiteral("article_title"), QStringLiteral("\"") + title.join(QStringLiteral("\"+\"")) + QStringLiteral("\""));
 
         /// Author
-        const QStringList authors = p->splitRespectingQuotationMarks(query[queryKeyAuthor]);
+        const QStringList authors = OnlineSearchAbstract::splitRespectingQuotationMarks(query[queryKeyAuthor]);
         if (!authors.isEmpty())
             q.addQueryItem(QStringLiteral("author"), QStringLiteral("\"") + authors.join(QStringLiteral("\"+\"")) + QStringLiteral("\""));
 
@@ -87,12 +87,13 @@ public:
     }
 };
 
+const QString OnlineSearchIEEEXplore::OnlineSearchIEEEXplorePrivate::xsltFilenameBase = QStringLiteral("ieeexploreapiv1-to-bibtex.xsl");
 const QUrl OnlineSearchIEEEXplore::OnlineSearchIEEEXplorePrivate::apiUrl(QStringLiteral("https://ieeexploreapi.ieee.org/api/v1/search/articles?format=xml&apikey=") + InternalNetworkAccessManager::reverseObfuscate("\x15\x65\x4b\x2a\x37\x5f\x78\x12\x44\x70\xf8\x8e\x85\xe0\xdb\xae\xb\x7a\x7e\x46\xab\x93\xbc\xc8\xdb\xa8\xa5\xd2\xee\x96\x7e\x7\x37\x54\xa3\xd4\x2b\x5e\x81\xe6\x6f\x17\xb3\xd6\x7b\x1f\x1a\x60"));
 
 OnlineSearchIEEEXplore::OnlineSearchIEEEXplore(QObject *parent)
         : OnlineSearchAbstract(parent), d(new OnlineSearchIEEEXplore::OnlineSearchIEEEXplorePrivate(this))
 {
-    // nothing
+    /// nothing
 }
 
 OnlineSearchIEEEXplore::~OnlineSearchIEEEXplore()
@@ -103,7 +104,7 @@ OnlineSearchIEEEXplore::~OnlineSearchIEEEXplore()
 void OnlineSearchIEEEXplore::startSearch(const QMap<QString, QString> &query, int numResults)
 {
     m_hasBeenCanceled = false;
-    emit progress(curStep = 0, numSteps = 2);
+    emit progress(curStep = 0, numSteps = 1);
 
     QNetworkRequest request(d->buildQueryUrl(query, numResults));
 
@@ -116,6 +117,8 @@ void OnlineSearchIEEEXplore::startSearch(const QMap<QString, QString> &query, in
     QNetworkReply *reply = InternalNetworkAccessManager::instance().get(request);
     InternalNetworkAccessManager::instance().setNetworkReplyTimeout(reply);
     connect(reply, &QNetworkReply::finished, this, &OnlineSearchIEEEXplore::doneFetchingXML);
+
+    refreshBusyProperty();
 }
 
 void OnlineSearchIEEEXplore::doneFetchingXML()
@@ -148,7 +151,7 @@ void OnlineSearchIEEEXplore::doneFetchingXML()
             /// use XSL transformation to get BibTeX document from XML result
             const QString bibTeXcode = EncoderXML::instance().decode(d->xslt.transform(xmlCode));
             if (bibTeXcode.isEmpty()) {
-                qCWarning(LOG_KBIBTEX_NETWORKING) << "XSL tranformation failed for data from " << reply->url().toDisplayString();
+                qCWarning(LOG_KBIBTEX_NETWORKING) << "XSL tranformation failed for data from " << InternalNetworkAccessManager::removeApiKey(reply->url()).toDisplayString();
                 stopSearch(resultInvalidArguments);
             } else {
                 FileImporterBibTeX importer(this);
@@ -162,22 +165,27 @@ void OnlineSearchIEEEXplore::doneFetchingXML()
                     }
 
                     stopSearch(resultNoError);
-                    emit progress(curStep = numSteps, numSteps);
 
                     delete bibtexFile;
                 } else {
-                    qCWarning(LOG_KBIBTEX_NETWORKING) << "No valid BibTeX file results returned on request on" << reply->url().toDisplayString();
+                    qCWarning(LOG_KBIBTEX_NETWORKING) << "No valid BibTeX file results returned on request on" << InternalNetworkAccessManager::removeApiKey(reply->url()).toDisplayString();
                     stopSearch(resultUnspecifiedError);
                 }
             }
         }
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString();
+    }
+
+    refreshBusyProperty();
 }
 
 QString OnlineSearchIEEEXplore::label() const
 {
+#ifdef HAVE_KF5
     return i18n("IEEEXplore");
+#else // HAVE_KF5
+    //= onlinesearch-ieeexplore-label
+    return QObject::tr("IEEEXplore");
+#endif // HAVE_KF5
 }
 
 QString OnlineSearchIEEEXplore::favIconUrl() const
@@ -189,4 +197,3 @@ QUrl OnlineSearchIEEEXplore::homepage() const
 {
     return QUrl(QStringLiteral("https://ieeexplore.ieee.org/"));
 }
-
