@@ -29,9 +29,9 @@
 #define i18n(text) QObject::tr(text)
 #endif // HAVE_KF5
 
-#include "xsltransform.h"
-#include "encoderxml.h"
-#include "fileimporterbibtex.h"
+#include <XSLTransform>
+#include <EncoderXML>
+#include <FileImporterBibTeX>
 #include "internalnetworkaccessmanager.h"
 #include "logging_networking.h"
 
@@ -142,7 +142,12 @@ void OnlineSearchPubMed::startSearch(const QMap<QString, QString> &query, int nu
 
 QString OnlineSearchPubMed::label() const
 {
+#ifdef HAVE_KF5
     return i18n("PubMed");
+#else // HAVE_KF5
+    //= onlinesearch-pubmed-label
+    return QObject::tr("PubMed");
+#endif // HAVE_KF5
 }
 
 QString OnlineSearchPubMed::favIconUrl() const
