@@ -21,11 +21,11 @@
 #include <QNetworkReply>
 #include <QRegularExpression>
 
-#include "fileimporterbibtex.h"
+#include <FileImporterBibTeX>
 #include "internalnetworkaccessmanager.h"
 #include "logging_networking.h"
 
-OnlineSearchSimpleBibTeXDownload::OnlineSearchSimpleBibTeXDownload(QWidget *parent)
+OnlineSearchSimpleBibTeXDownload::OnlineSearchSimpleBibTeXDownload(QObject *parent)
         : OnlineSearchAbstract(parent)
 {
     /// nothing
