@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -25,18 +25,18 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 
-#include "fileexporterbibtexoutput.h"
-#include "file.h"
-#include "entry.h"
-#include "element.h"
-#include "macro.h"
+#include <File>
+#include <Entry>
+#include <Element>
+#include <Macro>
+#include <FileExporterBibTeXOutput>
 
 CheckBibTeX::CheckBibTeXResult CheckBibTeX::checkBibTeX(QSharedPointer<Element> &element, const File *file, QWidget *parent)
 {
     /// only entries are supported, no macros, preambles, ...
     QSharedPointer<Entry> entry = element.dynamicCast<Entry>();
     if (entry.isNull())
-        return InvalidData;
+        return CheckBibTeXResult::InvalidData;
     else
         return checkBibTeX(entry, file, parent);
 }
@@ -57,7 +57,7 @@ CheckBibTeX::CheckBibTeXResult CheckBibTeX::checkBibTeX(QSharedPointer<Entry> &e
     Value crossRefVal = entry->value(Entry::ftCrossRef);
     if (!crossRefVal.isEmpty() && file != nullptr) {
         crossRefStr = PlainTextValue::text(crossRefVal);
-        QSharedPointer<Entry> crossRefDest = file->containsKey(crossRefStr, File::etEntry).dynamicCast<Entry>();
+        QSharedPointer<Entry> crossRefDest = file->containsKey(crossRefStr, File::ElementType::Entry).dynamicCast<Entry>();
         if (!crossRefDest.isNull())
             dummyFile << crossRefDest;
         else
@@ -75,14 +75,14 @@ CheckBibTeX::CheckBibTeXResult CheckBibTeX::checkBibTeX(QSharedPointer<Entry> &e
     QByteArray ba;
     QBuffer buffer(&ba);
     buffer.open(QIODevice::WriteOnly);
-    FileExporterBibTeXOutput exporter(FileExporterBibTeXOutput::BibTeXLogFile, parent);
+    FileExporterBibTeXOutput exporter(FileExporterBibTeXOutput::OutputType::BibTeXLogFile, parent);
     bool exporterResult = exporter.save(&buffer, &dummyFile, &bibtexOuput);
     buffer.close();
 
     if (!exporterResult) {
         QApplication::restoreOverrideCursor();
         KMessageBox::errorList(parent, i18n("Running BibTeX failed.\n\nSee the following output to trace the error:"), bibtexOuput, i18n("Running BibTeX failed."));
-        return FailedToCheck;
+        return CheckBibTeXResult::FailedToCheck;
     }
 
     /// define variables how to parse BibTeX's output
@@ -136,14 +136,14 @@ CheckBibTeX::CheckBibTeXResult CheckBibTeX::checkBibTeX(QSharedPointer<Entry> &e
         }
     }
 
-    CheckBibTeXResult result = NoProblem;
+    CheckBibTeXResult result = CheckBibTeXResult::NoProblem;
     QApplication::restoreOverrideCursor();
     if (!errorPlainText.isEmpty()) {
-        result = BibTeXWarning;
+        result = CheckBibTeXResult::BibTeXWarning;
         KMessageBox::information(parent, i18n("<qt><p>The following error was found:</p><pre>%1</pre></qt>", errorPlainText), i18n("Errors found"));
     } else if (!warnings.isEmpty()) {
         KMessageBox::informationList(parent, i18n("The following warnings were found:"), warnings, i18n("Warnings found"));
-        result = BibTeXError;
+        result = CheckBibTeXResult::BibTeXError;
     } else
         KMessageBox::information(parent, i18n("No warnings or errors were found.%1", crossRefStr.isEmpty() ? QString() : i18n("\n\nSome fields missing in this entry were taken from the crossref'ed entry '%1'.", crossRefStr)), i18n("No Errors or Warnings"));
 
