@@ -20,17 +20,17 @@
 
 #include <QFormLayout>
 #include <QCheckBox>
+#include <QComboBox>
 
-#include <KComboBox>
 #include <KLocalizedString>
 
-#include "preferences.h"
-#include "guihelper.h"
-#include "italictextitemmodel.h"
-#include "fileview.h"
-#include "models/filemodel.h"
-#include "value.h"
-#include "file.h"
+#include <Preferences>
+#include <Value>
+#include <File>
+#include <GUIHelper>
+#include <ItalicTextItemModel>
+#include <file/FileView>
+#include <models/FileModel>
 
 FileSettings::FileSettings(QWidget *parent)
         : FileSettingsWidget(parent), m_fileView(nullptr)
@@ -70,7 +70,7 @@ void FileSettings::currentFileChangedSlot() {
 
 void FileSettings::flagsChangedSlot(const OpenFileInfo::StatusFlags statusFlags)
 {
-    if (statusFlags.testFlag(OpenFileInfo::Open)) {
+    if (statusFlags.testFlag(OpenFileInfo::StatusFlag::Open)) {
         File *file = m_fileView != nullptr && m_fileView->fileModel() != nullptr ? m_fileView->fileModel()->bibliographyFile() : nullptr;
         loadProperties(file);
     }
