@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,22 +24,22 @@
 #include <QGridLayout>
 #include <QStringListModel>
 #include <QScrollBar>
+#include <QLineEdit>
+#include <QComboBox>
 #include <QTimer>
 #include <QSortFilterProxyModel>
 #include <QAction>
 
-#include <KLineEdit>
-#include <KComboBox>
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KToggleAction>
 #include <KSharedConfig>
 
-#include "bibtexfields.h"
-#include "entry.h"
-#include "fileview.h"
-#include "valuelistmodel.h"
-#include "models/filemodel.h"
+#include <BibTeXFields>
+#include <Entry>
+#include <file/FileView>
+#include <ValueListModel>
+#include <models/FileModel>
 
 class ValueList::ValueListPrivate
 {
@@ -56,8 +56,8 @@ public:
     QTreeView *treeviewFieldValues;
     ValueListModel *model;
     QSortFilterProxyModel *sortingModel;
-    KComboBox *comboboxFieldNames;
-    KLineEdit *lineeditFilter;
+    QComboBox *comboboxFieldNames;
+    QLineEdit *lineeditFilter;
     const int countWidth;
     QAction *assignSelectionAction;
     QAction *removeSelectionAction;
@@ -68,7 +68,13 @@ public:
             : p(parent), config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc"))), configGroupName(QStringLiteral("Value List Docklet")),
           configKeyFieldName(QStringLiteral("FieldName")), configKeyShowCountColumn(QStringLiteral("ShowCountColumn")),
           configKeySortByCountAction(QStringLiteral("SortByCountAction")), configKeyHeaderState(QStringLiteral("HeaderState")),
-          fileView(nullptr), model(nullptr), sortingModel(nullptr), countWidth(8 + parent->fontMetrics().width(i18n("Count"))) {
+          fileView(nullptr), model(nullptr), sortingModel(nullptr),
+#if QT_VERSION >= 0x050b00
+          countWidth(8 + parent->fontMetrics().horizontalAdvance(i18n("Count")))
+#else // QT_VERSION >= 0x050b00
+          countWidth(8 + parent->fontMetrics().width(i18n("Count")))
+#endif // QT_VERSION >= 0x050b00
+    {
         setupGUI();
         initialize();
     }
@@ -77,10 +83,11 @@ public:
         QBoxLayout *layout = new QVBoxLayout(p);
         layout->setMargin(0);
 
-        comboboxFieldNames = new KComboBox(true, p);
+        comboboxFieldNames = new QComboBox(p);
+        comboboxFieldNames->setEditable(true);
         layout->addWidget(comboboxFieldNames);
 
-        lineeditFilter = new KLineEdit(p);
+        lineeditFilter = new QLineEdit(p);
         layout->addWidget(lineeditFilter);
         lineeditFilter->setClearButtonEnabled(true);
         lineeditFilter->setPlaceholderText(i18n("Filter value list"));
@@ -122,7 +129,7 @@ public:
         p->setEnabled(false);
 
         connect(comboboxFieldNames, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated), p, &ValueList::fieldNamesChanged);
-        connect(comboboxFieldNames, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated), lineeditFilter, &KLineEdit::clear);
+        connect(comboboxFieldNames, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated), lineeditFilter, &QLineEdit::clear);
         connect(treeviewFieldValues, &QTreeView::activated, p, &ValueList::listItemActivated);
         connect(delegate, &ValueListDelegate::closeEditor, treeviewFieldValues, &QTreeView::reset);
 
@@ -185,7 +192,7 @@ public:
         QAbstractItemModel *usedModel = model;
         if (usedModel != nullptr) {
             model->setShowCountColumn(showCountColumnAction->isChecked());
-            model->setSortBy(sortByCountAction->isChecked() ? ValueListModel::SortByCount : ValueListModel::SortByText);
+            model->setSortBy(sortByCountAction->isChecked() ? ValueListModel::SortBy::Count : ValueListModel::SortBy::Text);
 
             if (sortingModel != nullptr) delete sortingModel;
             sortingModel = new QSortFilterProxyModel(p);
@@ -198,7 +205,7 @@ public:
             sortingModel->setFilterKeyColumn(0);
             sortingModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
             sortingModel->setFilterRole(ValueListModel::SearchTextRole);
-            connect(lineeditFilter, &KLineEdit::textEdited, sortingModel, &QSortFilterProxyModel::setFilterFixedString);
+            connect(lineeditFilter, &QLineEdit::textEdited, sortingModel, &QSortFilterProxyModel::setFilterFixedString);
             sortingModel->setSortLocaleAware(true);
             usedModel = sortingModel;
         }
@@ -223,7 +230,9 @@ public:
 ValueList::ValueList(QWidget *parent)
         : QWidget(parent), d(new ValueListPrivate(this))
 {
-    QTimer::singleShot(500, this, &ValueList::delayedResize);
+    QTimer::singleShot(500, this, [this]() {
+        resizeEvent(nullptr);
+    });
 }
 
 ValueList::~ValueList()
@@ -268,7 +277,7 @@ void ValueList::listItemActivated(const QModelIndex &index)
 
     SortFilterFileModel::FilterQuery fq;
     fq.terms << itemText;
-    fq.combination = SortFilterFileModel::EveryTerm;
+    fq.combination = SortFilterFileModel::FilterCombination::EveryTerm;
     fq.field = fieldText;
     fq.searchPDFfiles = false;
 
@@ -283,7 +292,7 @@ void ValueList::searchSelection()
     if (fieldText.isEmpty()) fieldText = d->comboboxFieldNames->currentText();
 
     SortFilterFileModel::FilterQuery fq;
-    fq.combination = SortFilterFileModel::EveryTerm;
+    fq.combination = SortFilterFileModel::FilterCombination::EveryTerm;
     fq.field = fieldText;
     const auto selectedIndexes = d->treeviewFieldValues->selectionModel()->selectedIndexes();
     for (const QModelIndex &index : selectedIndexes) {
@@ -439,18 +448,13 @@ void ValueList::showCountColumnToggled()
 void ValueList::sortByCountToggled()
 {
     if (d->model != nullptr)
-        d->model->setSortBy(d->sortByCountAction->isChecked() ? ValueListModel::SortByCount : ValueListModel::SortByText);
+        d->model->setSortBy(d->sortByCountAction->isChecked() ? ValueListModel::SortBy::Count : ValueListModel::SortBy::Text);
 
     KConfigGroup configGroup(d->config, d->configGroupName);
     configGroup.writeEntry(d->configKeySortByCountAction, d->sortByCountAction->isChecked());
     d->config->sync();
 }
 
-void ValueList::delayedResize()
-{
-    resizeEvent(nullptr);
-}
-
 void ValueList::columnsChanged()
 {
     QByteArray headerState = d->treeviewFieldValues->header()->saveState();
