@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2020 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -19,7 +19,6 @@
 
 #include <QStringListModel>
 #include <QTimer>
-#include <QSignalMapper>
 #include <QGridLayout>
 #include <QLabel>
 #include <QPainter>
@@ -35,7 +34,7 @@
 #include <KService>
 #include <KMessageBox>
 
-#include "kbibtex.h"
+#include <KBibTeX>
 
 class DirOperatorWidget : public QWidget
 {
@@ -172,15 +171,15 @@ QVariant DocumentListModel::data(const QModelIndex &index, int role) const
     case Qt::DecorationRole: {
         /// determine mime type-based icon and overlays (e.g. for modified files)
         QStringList overlays;
-        if (openFileInfo->flags().testFlag(OpenFileInfo::Favorite))
+        if (openFileInfo->flags().testFlag(OpenFileInfo::StatusFlag::Favorite))
             overlays << QStringLiteral("favorites");
         else
             overlays << QString();
-        if (openFileInfo->flags().testFlag(OpenFileInfo::RecentlyUsed))
+        if (openFileInfo->flags().testFlag(OpenFileInfo::StatusFlag::RecentlyUsed))
             overlays << QStringLiteral("document-open-recent");
         else
             overlays << QString();
-        if (openFileInfo->flags().testFlag(OpenFileInfo::Open))
+        if (openFileInfo->flags().testFlag(OpenFileInfo::StatusFlag::Open))
             overlays << QStringLiteral("folder-open");
         else
             overlays << QString();
@@ -200,11 +199,11 @@ QVariant DocumentListModel::data(const QModelIndex &index, int role) const
             htmlText.append(i18n("<br/><small>located in <b>%1</b></small>", path));
         }
         QStringList flagListItems;
-        if (openFileInfo->flags().testFlag(OpenFileInfo::Favorite))
+        if (openFileInfo->flags().testFlag(OpenFileInfo::StatusFlag::Favorite))
             flagListItems << i18n("Favorite");
-        if (openFileInfo->flags().testFlag(OpenFileInfo::RecentlyUsed))
+        if (openFileInfo->flags().testFlag(OpenFileInfo::StatusFlag::RecentlyUsed))
             flagListItems << i18n("Recently Used");
-        if (openFileInfo->flags().testFlag(OpenFileInfo::Open))
+        if (openFileInfo->flags().testFlag(OpenFileInfo::StatusFlag::Open))
             flagListItems << i18n("Open");
         if (openFileInfo->isModified())
             flagListItems << i18n("Modified");
@@ -218,7 +217,7 @@ QVariant DocumentListModel::data(const QModelIndex &index, int role) const
         htmlText.append(QStringLiteral("</qt>"));
         return htmlText;
     }
-    case Qt::UserRole: return qVariantFromValue(openFileInfo);
+    case Qt::UserRole: return QVariant::fromValue(openFileInfo);
     default: return QVariant();
     }
 }
@@ -248,13 +247,21 @@ public:
     QAction *actionCloseFile, *actionOpenFile;
     KActionMenu *actionOpenMenu;
     QList<QAction *> openMenuActions;
-    KService::List openMenuServices;
-    QSignalMapper openMenuSignalMapper;
 
     DocumentListViewPrivate(DocumentListView *parent)
             : p(parent), actionAddToFav(nullptr), actionRemFromFav(nullptr), actionCloseFile(nullptr), actionOpenFile(nullptr), actionOpenMenu(nullptr)
     {
-        connect(&openMenuSignalMapper, static_cast<void(QSignalMapper::*)(int)>(&QSignalMapper::mapped), p, &DocumentListView::openFileWithService);
+        /// nothing
+    }
+
+    void openFileWithService(KService::Ptr service)
+    {
+        const QModelIndex modelIndex = p->currentIndex();
+        if (modelIndex != QModelIndex()) {
+            OpenFileInfo *ofi = qvariant_cast<OpenFileInfo *>(modelIndex.data(Qt::UserRole));
+            if (!ofi->isModified() || (KMessageBox::questionYesNo(p, i18n("The current document has to be saved before switching the viewer/editor component."), i18n("Save before switching?"), KGuiItem(i18n("Save document"), QIcon::fromTheme(QStringLiteral("document-save"))), KGuiItem(i18n("Do not switch"), QIcon::fromTheme(QStringLiteral("dialog-cancel")))) == KMessageBox::Yes && ofi->save()))
+                OpenFileInfoManager::instance().setCurrentFile(ofi, service);
+        }
     }
 };
 
@@ -264,7 +271,7 @@ DocumentListView::DocumentListView(OpenFileInfo::StatusFlag statusFlag, QWidget
     setContextMenuPolicy(Qt::ActionsContextMenu);
     setItemDelegate(new DocumentListDelegate(this));
 
-    if (statusFlag == OpenFileInfo::Open) {
+    if (statusFlag == OpenFileInfo::StatusFlag::Open) {
         d->actionCloseFile = new QAction(QIcon::fromTheme(QStringLiteral("document-close")), i18n("Close File"), this);
         connect(d->actionCloseFile, &QAction::triggered, this, &DocumentListView::closeFile);
         addAction(d->actionCloseFile);
@@ -277,7 +284,7 @@ DocumentListView::DocumentListView(OpenFileInfo::StatusFlag statusFlag, QWidget
     d->actionOpenMenu = new KActionMenu(QIcon::fromTheme(QStringLiteral("document-open")), i18n("Open with"), this);
     addAction(d->actionOpenMenu);
 
-    if (statusFlag == OpenFileInfo::Favorite) {
+    if (statusFlag == OpenFileInfo::StatusFlag::Favorite) {
         d->actionRemFromFav = new QAction(QIcon::fromTheme(QStringLiteral("favorites")), i18n("Remove from Favorites"), this);
         connect(d->actionRemFromFav, &QAction::triggered, this, &DocumentListView::removeFromFavorites);
         addAction(d->actionRemFromFav);
@@ -302,7 +309,7 @@ void DocumentListView::addToFavorites()
     QModelIndex modelIndex = currentIndex();
     if (modelIndex != QModelIndex()) {
         OpenFileInfo *ofi = qvariant_cast<OpenFileInfo *>(modelIndex.data(Qt::UserRole));
-        ofi->addFlags(OpenFileInfo::Favorite);
+        ofi->addFlags(OpenFileInfo::StatusFlag::Favorite);
     }
 }
 
@@ -311,7 +318,7 @@ void DocumentListView::removeFromFavorites()
     QModelIndex modelIndex = currentIndex();
     if (modelIndex != QModelIndex()) {
         OpenFileInfo *ofi = qvariant_cast<OpenFileInfo *>(modelIndex.data(Qt::UserRole));
-        ofi->removeFlags(OpenFileInfo::Favorite);
+        ofi->removeFlags(OpenFileInfo::StatusFlag::Favorite);
     }
 }
 
@@ -324,16 +331,6 @@ void DocumentListView::openFile()
     }
 }
 
-void DocumentListView::openFileWithService(int i)
-{
-    QModelIndex modelIndex = currentIndex();
-    if (modelIndex != QModelIndex()) {
-        OpenFileInfo *ofi = qvariant_cast<OpenFileInfo *>(modelIndex.data(Qt::UserRole));
-        if (!ofi->isModified() || (KMessageBox::questionYesNo(this, i18n("The current document has to be saved before switching the viewer/editor component."), i18n("Save before switching?"), KGuiItem(i18n("Save document"), QIcon::fromTheme(QStringLiteral("document-save"))), KGuiItem(i18n("Do not switch"), QIcon::fromTheme(QStringLiteral("dialog-cancel")))) == KMessageBox::Yes && ofi->save()))
-            OpenFileInfoManager::instance().setCurrentFile(ofi, d->openMenuServices[i]);
-    }
-}
-
 void DocumentListView::closeFile()
 {
     QModelIndex modelIndex = currentIndex();
@@ -347,9 +344,9 @@ void DocumentListView::currentChanged(const QModelIndex &current, const QModelIn
 {
     bool hasCurrent = current != QModelIndex();
     OpenFileInfo *ofi = hasCurrent ? qvariant_cast<OpenFileInfo *>(current.data(Qt::UserRole)) : nullptr;
-    bool isOpen = hasCurrent ? ofi->flags().testFlag(OpenFileInfo::Open) : false;
-    bool isFavorite = hasCurrent ? ofi->flags().testFlag(OpenFileInfo::Favorite) : false;
-    bool hasName = hasCurrent ? ofi->flags().testFlag(OpenFileInfo::HasName) : false;
+    bool isOpen = hasCurrent ? ofi->flags().testFlag(OpenFileInfo::StatusFlag::Open) : false;
+    bool isFavorite = hasCurrent ? ofi->flags().testFlag(OpenFileInfo::StatusFlag::Favorite) : false;
+    bool hasName = hasCurrent ? ofi->flags().testFlag(OpenFileInfo::StatusFlag::HasName) : false;
 
     if (d->actionOpenFile != nullptr)
         d->actionOpenFile->setEnabled(hasCurrent && !isOpen);
@@ -363,18 +360,16 @@ void DocumentListView::currentChanged(const QModelIndex &current, const QModelIn
     for (QAction *action : const_cast<const QList<QAction *> &>(d->openMenuActions)) {
         d->actionOpenMenu->removeAction(action);
     }
-    d->openMenuServices.clear();
     if (ofi != nullptr) {
-        d->openMenuServices = ofi->listOfServices();
-        int i = 0;
-        for (KService::Ptr servicePtr : const_cast<const KService::List &>(d->openMenuServices)) {
+        const KService::List services = ofi->listOfServices();
+        for (KService::Ptr servicePtr : services) {
             QAction *menuItem = new QAction(QIcon::fromTheme(servicePtr->icon()), servicePtr->name(), this);
             d->actionOpenMenu->addAction(menuItem);
             d->openMenuActions << menuItem;
 
-            d->openMenuSignalMapper.setMapping(menuItem, i);
-            connect(menuItem, &QAction::triggered, &d->openMenuSignalMapper, static_cast<void(QSignalMapper::*)()>(&QSignalMapper::map));
-            ++i;
+            connect(menuItem, &QAction::triggered, this, [this, servicePtr]() {
+                d->openFileWithService(servicePtr);
+            });
         }
     }
     d->actionOpenMenu->setEnabled(!d->openMenuActions.isEmpty());
@@ -389,18 +384,18 @@ public:
     DirOperatorWidget *dirOperator;
 
     DocumentListPrivate(DocumentList *p) {
-        listOpenFiles = new DocumentListView(OpenFileInfo::Open, p);
-        DocumentListModel *model = new DocumentListModel(OpenFileInfo::Open, listOpenFiles);
+        listOpenFiles = new DocumentListView(OpenFileInfo::StatusFlag::Open, p);
+        DocumentListModel *model = new DocumentListModel(OpenFileInfo::StatusFlag::Open, listOpenFiles);
         listOpenFiles->setModel(model);
         p->addTab(listOpenFiles, QIcon::fromTheme(QStringLiteral("document-open")), i18n("Open Files"));
 
-        listRecentFiles = new DocumentListView(OpenFileInfo::RecentlyUsed, p);
-        model = new DocumentListModel(OpenFileInfo::RecentlyUsed, listRecentFiles);
+        listRecentFiles = new DocumentListView(OpenFileInfo::StatusFlag::RecentlyUsed, p);
+        model = new DocumentListModel(OpenFileInfo::StatusFlag::RecentlyUsed, listRecentFiles);
         listRecentFiles->setModel(model);
         p->addTab(listRecentFiles, QIcon::fromTheme(QStringLiteral("document-open-recent")), i18n("Recently Used"));
 
-        listFavorites = new DocumentListView(OpenFileInfo::Favorite, p);
-        model = new DocumentListModel(OpenFileInfo::Favorite, listFavorites);
+        listFavorites = new DocumentListView(OpenFileInfo::StatusFlag::Favorite, p);
+        model = new DocumentListModel(OpenFileInfo::StatusFlag::Favorite, listFavorites);
         listFavorites->setModel(model);
         p->addTab(listFavorites, QIcon::fromTheme(QStringLiteral("favorites")), i18n("Favorites"));
 
@@ -416,6 +411,11 @@ DocumentList::DocumentList(QWidget *parent)
     setDocumentMode(true);
 }
 
+DocumentList::~DocumentList()
+{
+    delete d;
+}
+
 void DocumentList::fileSelected(const KFileItem &item)
 {
     if (item.isFile() && item.isReadable())
