@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifndef KBIBTEX_PROGRAM_MDIWIDGET_H
@@ -20,12 +20,13 @@
 
 #include <QStackedWidget>
 #include <QModelIndex>
+#include <QUrl>
 
-#include <KUrl>
 #include <KService>
 
 #include "openfileinfo.h"
-#include <fileview.h>
+
+class FileView;
 
 namespace KParts
 {
@@ -40,29 +41,35 @@ class MDIWidget : public QStackedWidget
 
 public:
     explicit MDIWidget(QWidget *parent);
-    ~MDIWidget();
+    ~MDIWidget() override;
 
     FileView *fileView();
     OpenFileInfo *currentFile();
-    OpenFileInfoManager *getOpenFileInfoManager();
 
 public slots:
+    /**
+     * Make the MDI widget show a different file using a part
+     * as specified by a service.
+     * If the OpenFileInfo object is NULL, show no file but a
+     * Welcome widget instead.
+     * Retrieving the part to be used will be delegated to the
+     * OpenFileInfo object.
+     */
     void setFile(OpenFileInfo *openFileInfo, KService::Ptr servicePtr = KService::Ptr());
 
 signals:
     void setCaption(const QString &);
-    void documentSwitch(FileView *, FileView *);
+    void documentSwitched(FileView *, FileView *);
     void activePartChanged(KParts::Part *);
     void documentNew();
     void documentOpen();
-    void documentOpenURL(KUrl);
+    void documentOpenURL(const QUrl &);
 
 private:
     class MDIWidgetPrivate;
     MDIWidgetPrivate *d;
 
 private slots:
-    void slotCompleted(QObject *);
     void slotStatusFlagsChanged(OpenFileInfo::StatusFlags);
     void slotOpenLRU(const QModelIndex &);
 };
