@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2019 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2020 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -27,6 +27,7 @@
 #include <QAction>
 #include <QListWidget>
 #include <QApplication>
+#include <QRandomGenerator>
 
 #include <KAboutData>
 
@@ -39,7 +40,9 @@
 #include <onlinesearch/OnlineSearchIngentaConnect>
 #include <onlinesearch/OnlineSearchInspireHep>
 #include <onlinesearch/OnlineSearchIDEASRePEc>
+#ifdef HAVE_WEBENGINEWIDGETS
 #include <onlinesearch/OnlineSearchJStor>
+#endif // HAVE_WEBENGINEWIDGETS
 #include <onlinesearch/OnlineSearchMathSciNet>
 #include <onlinesearch/OnlineSearchMRLookup>
 #include <onlinesearch/OnlineSearchPubMed>
@@ -128,7 +131,9 @@ KBibTeXTest::KBibTeXTest(QWidget *parent)
     m_onlineSearchList << new OnlineSearchIEEEXplore(this);
     m_onlineSearchList << new OnlineSearchIngentaConnect(this);
     m_onlineSearchList << new OnlineSearchInspireHep(this);
+#ifdef HAVE_WEBENGINEWIDGETS
     m_onlineSearchList << new OnlineSearchJStor(this);
+#endif // HAVE_WEBENGINEWIDGETS
     m_onlineSearchList << new OnlineSearchMathSciNet(this);
     m_onlineSearchList << new OnlineSearchMRLookup(this);
     m_onlineSearchList << new OnlineSearchPubMed(this);
@@ -218,6 +223,8 @@ void KBibTeXTest::startOnlineSearchTests()
 
 void KBibTeXTest::onlineSearchStoppedSearch(int searchResult)
 {
+    if (m_currentOnlineSearch != m_onlineSearchList.constEnd())
+        disconnect(*m_currentOnlineSearch, &OnlineSearchAbstract::stoppedSearch, this, &KBibTeXTest::onlineSearchStoppedSearch);
     if (searchResult == OnlineSearchAbstract::resultNoError) {
         if (m_currentOnlineSearchNumFoundEntries == 0)
             addMessage(QString(QStringLiteral("Got no error message searching '%1', but found NO entries")).arg((*m_currentOnlineSearch)->label()), MessageStatus::Error);
@@ -249,7 +256,13 @@ void KBibTeXTest::processNextSearch()
         addMessage(QString(QStringLiteral("Searching '%1'")).arg((*m_currentOnlineSearch)->label()), MessageStatus::Info);
 
         QMap<QString, QString> query;
-        query.insert(OnlineSearchAbstract::queryKeyAuthor, QStringLiteral("smith"));
+        if (qobject_cast<OnlineSearchSemanticScholar *>(*m_currentOnlineSearch) != nullptr)
+            /// Semantic Scholar cannot search for last names, but for DOIs or arXiv IDs instead
+            query.insert(OnlineSearchAbstract::queryKeyFreeText, QStringLiteral("10.1002/smj.863"));
+        else {
+            static const QStringList lastNames{QStringLiteral("Smith"), QStringLiteral("Jones"), QStringLiteral("Andersson"), QStringLiteral("Ivanova"), QStringLiteral("Wang"), QStringLiteral("Gonzalez"), QStringLiteral("Garcia"), QStringLiteral("Lopez"), QStringLiteral("Ahmed"), QStringLiteral("Nkosi"), QStringLiteral("Kim"), QStringLiteral("Chen"), QStringLiteral("Devi"), QStringLiteral("Khan"), QStringLiteral("Johansson"), QStringLiteral("Sharipov"), QStringLiteral("Korhonen"), QStringLiteral("Muller"), QStringLiteral("Murphy"), QStringLiteral("Papadopoulos"), QStringLiteral("Rossi"), QStringLiteral("Hernandez"), QStringLiteral("Williams"), QStringLiteral("Zhang"), QStringLiteral("Singh"), QStringLiteral("Kumar")};
+            query.insert(OnlineSearchAbstract::queryKeyAuthor, lastNames[QRandomGenerator::global()->bounded(lastNames.count())]);
+        }
         connect(*m_currentOnlineSearch, &OnlineSearchAbstract::stoppedSearch, this, &KBibTeXTest::onlineSearchStoppedSearch);
         connect(*m_currentOnlineSearch, &OnlineSearchAbstract::foundEntry, this, [this]() {
             ++m_currentOnlineSearchNumFoundEntries;
